@@ -1,5 +1,5 @@
 /***************************************************************************
- *   copyright       : (C) 2003-2021 by Pascal Brachet                     *
+ *   copyright       : (C) 2003-2023 by Pascal Brachet                     *
  *   https://www.xm1math.net/texmaker/                                     *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -25,6 +25,7 @@
 #include <QScreen>
 #include <QWindow>
 #include <QGuiApplication>
+#include <QWebEngineSettings>
 
 
 
@@ -66,6 +67,7 @@ config->endGroup();
 
 progress = 0;
 view = new QWebEngineView(this);
+view->page()->settings()->setAttribute(QWebEngineSettings::LocalContentCanAccessRemoteUrls,true);
 if ( !home.isEmpty()) view->load(QUrl(home));
 index=home;
 ontop=false;
