@@ -1,24 +1,30 @@
 /***************************************************************************
- *   copyright       : (C) 2003-2017 by Pascal Brachet                     *
- *   http://www.xm1math.net/texmaker/                                      *
+ *   copyright       : (C) 2003-2023 by Pascal Brachet                     *
+ *   https://www.xm1math.net/texmaker/                                     *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   @license GPL-2.0+ <https://spdx.org/licenses/GPL-2.0+.html>           *
  ***************************************************************************/
 
 #include "configdialog.h"
 
 #include <QFontDatabase>
-#include <QTextCodec>
 #include <QFileDialog>
 #include <QColorDialog>
 #include <QDir>
 #include <QTableWidgetItem>
 #include <QDebug>
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+    #include <QtCore/QTextCodec>
+#else
+    #include <QtCore5Compat/QTextCodec>
+#endif
+
 #include "geticon.h"
 
 ConfigDialog::ConfigDialog(QWidget* parent): QDialog( parent)
@@ -41,10 +47,11 @@ foreach (int mib, QTextCodec::availableMibs())
 	if (codec->name()!="UTF-8") ui.comboBoxEncoding->addItem(codec->name());
 	}
 connect( ui.pushButtonAspell, SIGNAL(clicked()), this, SLOT(browseAspell()));
+
 connect( ui.pushButtonSvn, SIGNAL(clicked()), this, SLOT(browseSvn()));
 
-//ui.labelGetDic->setText( tr("Get dictionary at: %1").arg("<br><a href=\"http://wiki.services.openoffice.org/wiki/Dictionaries\">http://wiki.services.openoffice.org/wiki/Dictionaries</a>") );
-//ui.labelGetDic->setOpenExternalLinks(true);
+ui.labelGetDic->setText( tr("Get more dictionaries at: %1").arg("<a href=\"https://cgit.freedesktop.org/libreoffice/dictionaries/tree/\">freedesktop.org</a> (.aff & .dic required)") );
+ui.labelGetDic->setOpenExternalLinks(true);
 
 
 QTableWidgetItem *colorItem;
@@ -251,7 +258,7 @@ QString svndir=qgetenv("PROGRAMFILES");
 #else
 QString svndir="/usr/bin";
 #endif
-QString folder = QFileDialog::getExistingDirectory(this, tr("svn command directory"), svndir, 0);
+QString folder = QFileDialog::getExistingDirectory(this, tr("svn command directory"), svndir);
 if(!folder.isEmpty())
 {
 ui.lineEditSvn->setText( folder );    
