@@ -1,5 +1,5 @@
 /***************************************************************************
- *   copyright       : (C) 2003-2021 by Pascal Brachet                     *
+ *   copyright       : (C) 2003-2023 by Pascal Brachet                     *
  *   https://www.xm1math.net/texmaker/                                     *
  *                                                                         *
  *   based on qpdfview  Copyright 2012 Adam Reichold GPL                   *
@@ -148,6 +148,7 @@ DocumentView::DocumentView(QWidget* parent) : QGraphicsView(parent),
     m_returnToPage(-1),
     m_returnToLeft(0.0),
     m_returnToTop(0.0),
+    m_linkClicked(false),
     m_continuousMode(false),
     m_twoPagesMode(false),
     m_scaleMode(ScaleFactor),
@@ -769,7 +770,7 @@ if (m_pages.count()<1) return;
 
     top = top >= 0.0 ? top : 0.0;
     top = top <= 1.0 ? top : 1.0;
-
+    m_linkClicked=true;
     emit gotoDest(page, left, top);
 }
 
@@ -846,8 +847,11 @@ if(event->modifiers() & Qt::MetaModifier) {
 	qtKeyCode += Qt::META;
 }
 QKeySequence s1 = QKeySequence(qtKeyCode);
+
 if (hasFocus() && (s1.matches(QKeySequence(Qt::CTRL  | Qt::Key_Left))==QKeySequence::ExactMatch)) rotateLeft();
 else if (hasFocus() && (s1.matches(QKeySequence(Qt::CTRL  | Qt::Key_Right))==QKeySequence::ExactMatch)) rotateRight();
+else if (hasFocus() && (s1.matches(QKeySequence("Home"))==QKeySequence::ExactMatch)) firstPage();
+else if (hasFocus() && (s1.matches(QKeySequence("End"))==QKeySequence::ExactMatch)) lastPage();
 else QGraphicsView::keyPressEvent(event);
 }
 
@@ -917,7 +921,7 @@ void DocumentView::wheelEvent(QWheelEvent* event)
 if (m_pages.count()<1) return;
     if(event->modifiers() == Qt::ControlModifier)
     {
-        if(event->angleDelta().x() > 0)
+        if(event->angleDelta().y() > 0)
         {
             emit requestZoomIn();//zoomIn();
         }
@@ -931,7 +935,7 @@ if (m_pages.count()<1) return;
     }
     else if(event->modifiers() == Qt::ShiftModifier)
     {
-        if(event->angleDelta().x() > 0)
+        if(event->angleDelta().y() > 0)
         {
             rotateLeft();
         }
@@ -947,7 +951,7 @@ if (m_pages.count()<1) return;
     {
         if(!m_continuousMode)
         {
-            if(event->angleDelta().x() > 0 && verticalScrollBar()->value() == verticalScrollBar()->minimum() && m_currentPage > 1)
+            if(event->angleDelta().y() > 0 && verticalScrollBar()->value() == verticalScrollBar()->minimum() && m_currentPage > 1)
             {
                 previousPage();
 
@@ -956,7 +960,7 @@ if (m_pages.count()<1) return;
                 event->accept();
                 return;
             }
-            else if(event->angleDelta().x() < 0 && verticalScrollBar()->value() == verticalScrollBar()->maximum() && m_currentPage != currentPageForPage(m_numberOfPages))
+            else if(event->angleDelta().y() < 0 && verticalScrollBar()->value() == verticalScrollBar()->maximum() && m_currentPage != currentPageForPage(m_numberOfPages))
             {
                 nextPage();
 
@@ -1061,9 +1065,17 @@ void DocumentView::preparePages()
       progressDialog->setValue(index);
        //QApplication::processEvents();
         PageItem* page = new PageItem(&m_mutex, m_document, index);
+#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
+qreal extra=1.0;
+if (qApp->devicePixelRatio()>1) extra=qApp->devicePixelRatio();
+page->setPhysicalDpi(int(physicalDpiX()*extra), int(physicalDpiY()*extra));
+#else
 const int dpr = int(qApp->devicePixelRatio());
 if (qApp->devicePixelRatio()>=2) page->setPhysicalDpi(physicalDpiX()*dpr, physicalDpiY()*dpr);
 else page->setPhysicalDpi(physicalDpiX(), physicalDpiY());
+#endif
+
+
 
         m_pagesScene->addItem(page);
         m_pages.append(page);
@@ -1308,8 +1320,8 @@ void DocumentView::prepareView(qreal changeLeft, qreal changeTop)
     }
 
     setSceneRect(left, top, width, height);
-
-    horizontalScrollBar()->setValue(horizontalValue);
+    if (!m_linkClicked) horizontalScrollBar()->setValue(horizontalValue);
+    else m_linkClicked=false;
     verticalScrollBar()->setValue(verticalValue);
     viewport()->update();
 }
