@@ -1,26 +1,28 @@
 /***************************************************************************
- *   copyright       : (C) 2003-2017 by Pascal Brachet                     *
- *   http://www.xm1math.net/texmaker/                                      *
+ *   copyright       : (C) 2003-2023 by Pascal Brachet                     *
+ *   https://www.xm1math.net/texmaker/                                     *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   @license GPL-2.0+ <https://spdx.org/licenses/GPL-2.0+.html>           *
  ***************************************************************************/
 
 #include "exportdialog.h"
+#include "cmdparser.h"
+
 
 
-#include <QTextCodec>
 #include <QFileDialog>
 #include <QDir>
 #include <QDirIterator>
 #include <QDebug>
-
 #include <QProcessEnvironment>
 
 
+
 ExportDialog::ExportDialog(QWidget* parent,QString f, QString ep): QDialog( parent)
 {
 setModal(true);
@@ -113,7 +115,9 @@ if (!extra_path.isEmpty())
 #endif
 qputenv("PATH", env.value("PATH").toLatin1());
 ui.plainTextEditResult->insertPlainText(commandline+"\n");
-proc->start(commandline);
+const cmdInfo commandInfo=splitCommand(commandline);
+proc->start(commandInfo.program,commandInfo.arguments);
+//proc->start(commandline);
 }
 
 void ExportDialog::readFromStderr()
