@@ -1,12 +1,13 @@
 /***************************************************************************
- *   copyright       : (C) 2003-2017 by Pascal Brachet                     *
- *   http://www.xm1math.net/texmaker/                                      *
+ *   copyright       : (C) 2003-2023 by Pascal Brachet                     *
+ *   https://www.xm1math.net/texmaker/                                     *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   @license GPL-2.0+ <https://spdx.org/licenses/GPL-2.0+.html>           *
  ***************************************************************************/
 
 #include "findwidget.h"
@@ -14,7 +15,11 @@
 #include <QDebug>
 #include <QTextCursor>
 #include <QMessageBox>
+#include <QRegularExpression>
+#include <QLineEdit>
+
 #include "geticon.h"
+#include "theme.h"
 
 FindWidget::FindWidget(QWidget* parent)
     : QWidget( parent)
@@ -34,6 +39,23 @@ ui.checkRegExp->setChecked( false );
 ui.checkSelection->setChecked( false );
 connect(ui.checkSelection, SIGNAL(toggled(bool)), this, SLOT(updateSelection(bool)));
 ui.extension->hide();
+QPalette pal( palette() );
+pal.setColor( QPalette::Active, QPalette::WindowText,Theme::grayColor );
+pal.setColor( QPalette::Inactive, QPalette::WindowText, Theme::grayColor );
+pal.setColor( QPalette::Disabled, QPalette::WindowText, Theme::grayColor );
+pal.setColor( QPalette::Active, QPalette::HighlightedText, Theme::grayColor );
+pal.setColor( QPalette::Inactive, QPalette::HighlightedText, Theme::grayColor );
+pal.setColor( QPalette::Disabled, QPalette::HighlightedText,Theme::grayColor );
+pal.setColor( QPalette::Active, QPalette::Base, Theme::grayColor );
+pal.setColor( QPalette::Inactive, QPalette::Base, Theme::grayColor );
+pal.setColor( QPalette::Disabled, QPalette::Base, Theme::grayColor);
+pal.setColor(QPalette::Window, Theme::darkbackgroundColor);
+setPalette( pal );
+ui.findButton->setStyleSheet(Theme::buttonSearchStyleSheet);
+ui.closeButton->setStyleSheet(Theme::buttonSearchStyleSheet);
+ui.moreButton->setStyleSheet(Theme::buttonSearchStyleSheet);
+ui.comboFind->setStyleSheet(Theme::comboboxSearchStyleSheet);
+//ui.comboFind->lineEdit()->setStyleSheet(Theme::lineeditSearchStyleSheet);
 updateGeometry();
  }
 
@@ -53,7 +75,7 @@ if ( !editor )
 
 if (ui.checkRegExp->isChecked())
   {
-  QRegExp regex(ui.comboFind->currentText());
+QRegularExpression regex(ui.comboFind->currentText());
   if (!regex.isValid()) 
     {
     QMessageBox::warning( this,tr("Error"), tr("Invalid regular expression."));
