@@ -1,5 +1,5 @@
 /***************************************************************************
- *   copyright       : (C) 2003-2021 by Pascal Brachet                     *
+ *   copyright       : (C) 2003-2023 by Pascal Brachet                     *
  *   https://www.xm1math.net/texmaker/                                     *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -121,25 +121,42 @@ void IconDelegate::drawDecoration(QPainter *painter, const QStyleOptionViewItem
     if (!pixmap.isNull() && !rect.isEmpty()) {
         if (option.state & QStyle::State_Selected) {
             bool enabled = option.state & QStyle::State_Enabled;
-            QPixmap *pm = selected(pixmap, option.palette, enabled);
-	    #if (QT_VERSION >= QT_VERSION_CHECK(5, 0, 0))
-            if (qApp->devicePixelRatio()>=2)
+
+        #if (QT_VERSION >= QT_VERSION_CHECK(5, 13, 0))
+        QPixmap pm = selectedPixmap(pixmap, option.palette, option.state & QStyle::State_Enabled);
+        if (qApp->devicePixelRatio()>=2)
             {
-        pm->setDevicePixelRatio(qApp->devicePixelRatio());
-        p-=QPoint(16,0);
-          }
-	    #endif
+            pm.setDevicePixelRatio(qApp->devicePixelRatio());
+            p-=QPoint(16,0);
+            }
+            painter->drawPixmap(p,pm);
+        #else
+        QPixmap *pm = selected(pixmap, option.palette, enabled);
+        if (qApp->devicePixelRatio()>=2)
+            {
+            pm->setDevicePixelRatio(qApp->devicePixelRatio());
+            p-=QPoint(16,0);
+            }
             painter->drawPixmap(p, *pm);
+        #endif
         } else {
-QPixmap *pm=selected(pixmap, option.palette, true);
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 0, 0))
-            if (qApp->devicePixelRatio()>=2)
+        #if (QT_VERSION >= QT_VERSION_CHECK(5, 13, 0))
+        QPixmap pm = selectedPixmap(pixmap, option.palette, true);
+           if (qApp->devicePixelRatio()>=2)
+            {
+                pm.setDevicePixelRatio(qApp->devicePixelRatio());
+                p-=QPoint(16,0);
+            }
+            painter->drawPixmap(p,pm);
+        #else
+        QPixmap *pm=selected(pixmap, option.palette, true);
+           if (qApp->devicePixelRatio()>=2)
             {
                 pm->setDevicePixelRatio(qApp->devicePixelRatio());
                 p-=QPoint(16,0);
             }
-#endif
             painter->drawPixmap(p, *pm);
+            #endif
         }
     }
 }
@@ -275,7 +292,7 @@ void IconDelegate::doLayout(const QStyleOptionViewItem &option,
         display.setRect(x, y, w, h);
         break; }
     default:
-        qWarning("doLayout: decoration positon is invalid");
+        qWarning("doLayout: decoration position is invalid");
         decoration = *pixmapRect;
         break;
     }
@@ -329,7 +346,33 @@ static QString qPixmapSerial(quint64 i, bool enabled)
 
     return QString((const QChar *)ptr, int(&arr[sizeof(arr) / sizeof(ushort)] - ptr));
 }
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 13, 0))
+QPixmap IconDelegate::selectedPixmap(const QPixmap &pixmap, const QPalette &palette, bool enabled)
+{
+    const QString key = qPixmapSerial(pixmap.cacheKey(), enabled);
+    QPixmap pm;
+    if (!QPixmapCache::find(key, &pm)) {
+        QImage img = pixmap.toImage().convertToFormat(QImage::Format_ARGB32_Premultiplied);
 
+        QColor color = palette.color(enabled ? QPalette::Normal : QPalette::Disabled,
+                                     QPalette::Highlight);
+        color.setAlphaF(0.3f);
+
+        QPainter painter(&img);
+        painter.setCompositionMode(QPainter::CompositionMode_SourceAtop);
+        painter.fillRect(0, 0, img.width(), img.height(), color);
+        painter.end();
+
+        pm = QPixmap(QPixmap::fromImage(img));
+        const int n = (img.sizeInBytes() >> 10) + 1;
+        if (QPixmapCache::cacheLimit() < n)
+            QPixmapCache::setCacheLimit(n);
+
+        QPixmapCache::insert(key, pm);
+    }
+    return pm;
+}
+#else
 QPixmap *IconDelegate::selected(const QPixmap &pixmap, const QPalette &palette, bool enabled) const
 {
     //QString key;
@@ -355,7 +398,7 @@ QPixmap *IconDelegate::selected(const QPixmap &pixmap, const QPalette &palette,
     }
     return pm;
 }
-
+#endif
 /*!
   \internal
 */
