@@ -1,5 +1,5 @@
 /***************************************************************************
- *   copyright       : (C) 2003-2021 by Pascal Brachet                     *
+ *   copyright       : (C) 2003-2023 by Pascal Brachet                     *
  *   https://www.xm1math.net/texmaker/                                     *
  *                                                                         *
  *   addons by Luis Silvestre, Julián Moreno Patiño                        *
@@ -848,8 +848,8 @@ if (inlinecheckSpelling && pChecker && !textCursor().hasSelection())
       char ** wlst;
       QStringList suggWords;
       colstart=cpos-bpos;
-      if (data->misspelled[colstart]==true)
-      {
+       if ((data->misspelled.count()>0) && (data->misspelled[colstart]==true))
+       {
  	while ((colstart>=0) && (colstart<data->misspelled.count()) && (data->misspelled[colstart]==true))
 	{
 	colstart--;
@@ -863,7 +863,7 @@ if (inlinecheckSpelling && pChecker && !textCursor().hasSelection())
 	c.setPosition(bpos+colstart,QTextCursor::MoveAnchor);
 	c.setPosition(bpos+colend,QTextCursor::KeepAnchor);
 	text=c.selectedText();
- 
+
 	li=c.blockNumber();
 	cols=colstart;
         if (text.length()>1 && colend>colstart)
@@ -882,11 +882,11 @@ if (inlinecheckSpelling && pChecker && !textCursor().hasSelection())
 					{
 					suggWords.clear();
                     spellingLookup.clear();
-					for (int i=0; i < ns; i++) 
+					for (int i=0; i < ns; i++)
 						{
 						suggWords.append(codec->toUnicode(wlst[i]));
 					//free(wlst[i]);
-						} 
+						}
 				//free(wlst);
 					pChecker->free_list(&wlst, ns);
 					if (!suggWords.isEmpty())
@@ -968,7 +968,7 @@ connect(a, SIGNAL(triggered()), this, SLOT(jumpToPdf()));
 menu->addAction(a);
 
 // QInputContext *qic = inputContext();
-// if (qic) 
+// if (qic)
 //     {
 //     QList<QAction *> imActions = qic->actions();
 //     for (int i = 0; i < imActions.size(); ++i)
@@ -1070,9 +1070,9 @@ if (c.hasSelection())
         QRegularExpressionMatch expr1Match=expr1.match(c.selectedText(),pos);
         if (expr1Match.hasMatch())
             {
-            texts << expr1Match.captured(0);
-            pos=expr1Match.capturedStart();
-            pos += expr1Match.capturedLength(0);
+            texts << expr1Match.captured(1);
+            pos=expr1Match.capturedStart(1);
+            pos += expr1Match.capturedLength(1);
             }
         else pos=-1;
 	    }
@@ -1112,6 +1112,8 @@ if (line<=numoflines())
 
 void LatexEditor::commentSelection()
 {
+QFileInfo fi(fname);
+bool asy =(!fname.startsWith("untitled") && (fi.suffix()=="asy")) ;
 bool go=true;
 QTextCursor cur=textCursor();
 if (cur.hasSelection())
@@ -1122,8 +1124,17 @@ if (cur.hasSelection())
 	cur.movePosition(QTextCursor::StartOfBlock,QTextCursor::MoveAnchor);
 	while ( cur.position() < end && go)
 		{
-		cur.insertText("%");
-		end++;
+		if (asy)
+			{
+			cur.insertText("//");
+			end++;
+			end++;
+			}
+		else
+			{
+			cur.insertText("%");
+			end++;
+			}
 		go=cur.movePosition(QTextCursor::NextBlock,QTextCursor::MoveAnchor);
 		}
       }
@@ -1155,6 +1166,8 @@ if (cur.hasSelection())
 
 void LatexEditor::uncommentSelection()
 {
+QFileInfo fi(fname);
+bool asy =(!fname.startsWith("untitled") && (fi.suffix()=="asy")) ;
 bool go=true;
 int pos=0;
 QTextCursor cur=textCursor();
@@ -1167,22 +1180,41 @@ int start=cur.selectionStart();
 int end=cur.selectionEnd();
 cur.setPosition(start,QTextCursor::MoveAnchor);
 cur.movePosition(QTextCursor::StartOfBlock,QTextCursor::MoveAnchor);
-while ( cur.position() < end && go)
-    {
-    cur.movePosition(QTextCursor::NextCharacter,QTextCursor::KeepAnchor);
-    while (cur.selectedText()=="\t" || cur.selectedText()==" ")
-    {
-    pos=cur.selectionEnd();
-    cur.setPosition(pos,QTextCursor::MoveAnchor);
-    cur.movePosition(QTextCursor::NextCharacter,QTextCursor::KeepAnchor);
-    }	
-    if (cur.selectedText()=="%") 
-        {
-        cur.removeSelectedText();
-        end--;
-        }
-    go=cur.movePosition(QTextCursor::NextBlock,QTextCursor::MoveAnchor);
-    }
+if (asy)
+	{
+	while ( cur.position() < end && go)
+		{
+		cur.movePosition(QTextCursor::NextCharacter,QTextCursor::KeepAnchor);
+		cur.movePosition(QTextCursor::NextCharacter,QTextCursor::KeepAnchor);
+		if (cur.selectedText()=="//")
+			{
+			cur.removeSelectedText();
+			end--;
+			end--;
+			}
+		go=cur.movePosition(QTextCursor::NextBlock,QTextCursor::MoveAnchor);
+		}
+	}
+else
+	{
+	while ( cur.position() < end && go)
+		{
+		cur.movePosition(QTextCursor::NextCharacter,QTextCursor::KeepAnchor);
+		while (cur.selectedText()=="\t" || cur.selectedText()==" ")
+		{
+		pos=cur.selectionEnd();
+		cur.setPosition(pos,QTextCursor::MoveAnchor);
+		cur.movePosition(QTextCursor::NextCharacter,QTextCursor::KeepAnchor);
+		}
+		if (cur.selectedText()=="%")
+			{
+			cur.removeSelectedText();
+			end--;
+			}
+		go=cur.movePosition(QTextCursor::NextBlock,QTextCursor::MoveAnchor);
+		}
+	}
+
 }
 
 void LatexEditor::unindentSelection()
