@@ -1,14 +1,15 @@
 /***************************************************************************
- *   copyright       : (C) 2003-2017 by Pascal Brachet                     *
- *   http://www.xm1math.net/texmaker/                                      *
- *   addons by Luis Silvestre                                              *
- *   contains some code from CLedit (C) 2010 Heinz van Saanen -GPL         *
+ *   copyright       : (C) 2003-2023 by Pascal Brachet                     *
+ *   https://www.xm1math.net/texmaker/                                     *
  *                                                                         *
+ *   addons by Luis Silvestre, Julián Moreno Patiño                        *
+ *   contains some code from CLedit (C) 2010 Heinz van Saanen -GPL         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   @license GPL-2.0+ <https://spdx.org/licenses/GPL-2.0+.html>           *
  ***************************************************************************/
 
 #ifndef LATEXEDITOR_H
@@ -30,8 +31,8 @@
 #include <QMutex>
 #include <QQueue>
 #include <QDebug>
-#include <QScriptEngine>
-//#include <QScriptEngineDebugger>
+#include <QJSEngine>
+
 
 #include "latexhighlighter.h"
 #include "textblockselection.h"
@@ -200,7 +201,8 @@ bool highlightLine;
 QString copyBlockSelection() const;
 QColor colorBackground, colorLine, colorHighlight, colorCursor;
 
-QScriptEngine fScriptEngine;
+
+QJSEngine fScriptEngine;
 
 
 private slots:
