@@ -1,16 +1,23 @@
 /***************************************************************************
- *   copyright       : (C) 2003-2017 by Pascal Brachet                     *
- *   http://www.xm1math.net/texmaker/                                      *
+ *   copyright       : (C) 2003-2023 by Pascal Brachet                     *
+ *   https://www.xm1math.net/texmaker/                                     *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   @license GPL-2.0+ <https://spdx.org/licenses/GPL-2.0+.html>           *
  ***************************************************************************/
 
 
 #include <QtGui>
+#include <QRegularExpression>
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+    #include <QtCore/QTextCodec>
+#else
+    #include <QtCore5Compat/QTextCodec>
+#endif
 
 #include "latexhighlighter.h"
 #include "latexeditor.h"
@@ -86,7 +93,9 @@ rehighlight();
 
 void LatexHighlighter::highlightBlock(const QString &text)
 {
-QRegExp rxSweave("<<(.*)>>=");
+// currentBlock().blockFormat().setIndent(1);
+// qDebug() << text << currentBlock().blockFormat().indent();
+QRegularExpression rxSweave("<<(.*)>>=");
 QStringList types;
 types << QLatin1String("article") << QLatin1String("book")
   << QLatin1String("booklet") << QLatin1String("inbook")
@@ -100,8 +109,8 @@ types << QLatin1String("article") << QLatin1String("book")
   << QLatin1String("online") << QLatin1String("mvproceedings")
   << QLatin1String("inproceedings") << QLatin1String("report")
   << QLatin1String("thesis") << QLatin1String("electronic") << QLatin1String("patent");
-QRegExp rxBib("@("+types.join("|")+")\\s*\\{\\s*(.*),", Qt::CaseInsensitive);
-rxBib.setMinimal(true);
+QRegularExpression rxBib("@("+types.join("|")+")\\s*\\{\\s*(.*),", QRegularExpression::CaseInsensitiveOption | QRegularExpression::InvertedGreedinessOption);
+
 
 const int StateStandard = 0;
 const int StateComment = 1;
@@ -180,8 +189,13 @@ setCurrentBlockUserData(blockData);
 /////////////////////
 
 /////////////////
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
 QRegExp rxverb("verb\\*?([^\\*])");
 QRegExp rxlst("lstinline(.)");
+#else
+QRegularExpression rxverb(QRegularExpression::anchoredPattern("verb\\*?([^\\*])"));
+QRegularExpression rxlst(QRegularExpression::anchoredPattern("lstinline(.)"));
+#endif
 QTextCharFormat structFormat;
 structFormat.setFontWeight(QFont::Bold);
 structFormat.setForeground(ColorKeyword);
@@ -226,7 +240,7 @@ while (i < text.length())
 			blockData->code[i]=1;
 			state=StateCommand;
 			}
-			buffer = QString::null;
+			buffer = QString();
 		} else
 		if (tmp=='$') {
 			setFormat( i, 1,ColorMath);
@@ -241,13 +255,13 @@ while (i < text.length())
 					blockData->code[i]=1;
 					}
 				}
-			buffer = QString::null;
+			buffer = QString();
 		} else
 		if (tmp== '%' ){
 			setFormat( i, 1,ColorComment);
 			state=StateComment;
 			blockData->code[i]=1;
-			buffer = QString::null;
+			buffer = QString();
 		} else
 		if (tmp== '{' ){
 			blockData->code[i]=1;
@@ -301,7 +315,7 @@ while (i < text.length())
 			if(poslab != -1) {state=StateMath;for (k=poslab; k <i ; k++) {if (k>0 && k<text.length()) blockData->code[k]=1;}}
 			poslab=buffer.indexOf("begin{gather*}") ;
 			if(poslab != -1) {state=StateMath;for (k=poslab; k <i ; k++) {if (k>0 && k<text.length()) blockData->code[k]=1;}}
-			buffer = QString::null;
+			buffer = QString();
 		} else
 		if (tmp== '<' ){
 			blockData->code[i]=1;
@@ -324,44 +338,44 @@ while (i < text.length())
 			  if ((posbib2 !=-1) && (posbib2>posbib)) setFormat(posbib,posbib2-posbib,structFormat);
 			  for (k=posbib; k <i ; k++) {if (k>0 && k<text.length()) blockData->code[k]=1;}
 			  state=StateBib;
-			  buffer = QString::null;
+			  buffer = QString();
 			  }
 		} else
 		if (tmp== '=' ){
 			blockData->code[i]=1;
 			setFormat( i, 1,ColorStandard);
-			if(buffer.indexOf(rxSweave) != -1) {state=StateSweave;buffer = QString::null;}
+			if(buffer.indexOf(rxSweave) != -1) {state=StateSweave;buffer = QString();}
 		} else
 		if (tmp== '(' ){
 			blockData->code[i]=1;
 			setFormat( i, 1,ColorStandard);
 			state=StateStandard;
-			buffer = QString::null;
+			buffer = QString();
 		} else
 		if (tmp== ')' ){
 			blockData->code[i]=1;
 			setFormat( i, 1,ColorStandard);
 			state=StateStandard;
-			buffer = QString::null;
+			buffer = QString();
 		} else
 		if (isWordSeparator(tmp)){
 			blockData->code[i]=1;
 			setFormat( i, 1,ColorStandard);
-			//buffer = QString::null;
+			//buffer = QString();
 		} else
 		 {
 			setFormat( i, 1,ColorStandard);
 			state=StateStandard;
-			//buffer = QString::null;
+			//buffer = QString();
 		}
-//	buffer = QString::null;
+//	buffer = QString();
 	} break;
 	
 	case StateComment: {
 	setFormat( i, 1,ColorComment);
 	blockData->code[i]=1;
 	state=StateComment;
-	buffer = QString::null;
+	buffer = QString();
 	} break;
 
 	case StateMath: {
@@ -379,7 +393,7 @@ while (i < text.length())
 					blockData->code[i]=1;
 					}
 				}
-		buffer = QString::null;
+		buffer = QString();
 		} else if (tmp== '\\') {
 			if (next==']' || next==')')
 				{
@@ -392,7 +406,7 @@ while (i < text.length())
 					setFormat( i, 1,ColorMath);
 					blockData->code[i]=1;
 					}
-				buffer = QString::null;
+				buffer = QString();
 				}
 			else if (next=='$')
 				{
@@ -487,7 +501,7 @@ while (i < text.length())
 			    setFormat(pos+4,9,ColorStandard);
 			    for (k=i-12; k <i-8 ; k++) {if (k>0 && k<text.length()) blockData->code[k]=1;}
 			}
-		buffer = QString::null;
+		buffer = QString();
 		} else
 		 {
 			setFormat( i, 1,ColorMath);
@@ -536,7 +550,7 @@ while (i < text.length())
 			blockData->code[i]=1;
 			state=StateGraphicMath;
 			}
-	buffer = QString::null;
+	buffer = QString();
 	} break;
 	case StateGraphicAsyMath: {
 		tmp=text.at( i );
@@ -582,20 +596,38 @@ while (i < text.length())
 			blockData->code[i]=1;
 			state=StateGraphicAsyMath;
 			}
-	buffer = QString::null;
+	buffer = QString();
 	} break;
 	case StateCommand:{
 		tmp=text.at( i );
-		if (rxverb.exactMatch(buffer))
+        #if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
+        if (rxverb.exactMatch(buffer))
+        #else
+        QRegularExpressionMatch rxverbMatch=rxverb.match(buffer);
+        QRegularExpressionMatch rxlstMatch=rxlst.match(buffer);
+        if (rxverbMatch.hasMatch())
+        #endif
 				{
-				 verbflag=rxverb.cap(1).at(0);
+                #if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
+                verbflag=rxverb.cap(1).at(0);
+                #else
+				 verbflag=rxverbMatch.captured(1).at(0);
+                #endif
 				 blockData->code[i]=1;
 				 setFormat( i, 1,ColorCommand);
 				 state=StateVerbatim;
 		} else
-		if (rxlst.exactMatch(buffer))
+        #if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
+        if (rxlst.exactMatch(buffer))
+        #else
+		if (rxlstMatch.hasMatch())
+        #endif
 				{
-				 verbflag=rxlst.cap(1).at(0);
+                #if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
+                if (rxlst.exactMatch(buffer))
+                #else
+				 verbflag=rxlstMatch.captured(1).at(0);
+                #endif
 				 blockData->code[i]=1;
 				 setFormat( i, 1,ColorCommand);
 				 state=StateVerbatim;
@@ -713,12 +745,12 @@ while (i < text.length())
 					blockData->code[i]=1;
 					}
 				}
-			buffer = QString::null;
+			buffer = QString();
 		} else
 		if (tmp== '%' ){
 			setFormat( i, 1,ColorVerbatim);
 			blockData->code[i]=1;
-			buffer = QString::null;
+			buffer = QString();
 		} else
 		if (tmp== '{' ){
 			blockData->code[i]=1;
@@ -760,26 +792,26 @@ while (i < text.length())
 			    setFormat(pos+4,9,ColorStandard);
 			    for (k=i-12; k <i-8 ; k++) {if (k>0 && k<text.length()) blockData->code[k]=1;}
 			}
-			buffer = QString::null;
+			buffer = QString();
 		} else
 		if (tmp== '(' ){
 			blockData->code[i]=1;
 			setFormat( i, 1,ColorVerbatim);
-			buffer = QString::null;
+			buffer = QString();
 		} else
 		if (tmp== ')' ){
 			blockData->code[i]=1;
 			setFormat( i, 1,ColorVerbatim);
-			buffer = QString::null;
+			buffer = QString();
 		} else
 		if (isWordSeparator(tmp)){
 			blockData->code[i]=1;
 			setFormat( i, 1,ColorVerbatim);
-			buffer = QString::null;
+			buffer = QString();
 		} else
 		 {
 			setFormat( i, 1,ColorVerbatim);
-			//buffer = QString::null;
+			//buffer = QString();
 		}
        } break;
 	case StateVerbatimCommand:{
@@ -863,20 +895,20 @@ while (i < text.length())
 					blockData->code[i]=1;
 					}
 				}
-			buffer = QString::null;
+			buffer = QString();
 		} else
 		if (tmp== '/' && next=='/'){
 			setFormat( i, 1,ColorComment);
 			state=StateGraphicComment;
 			blockData->code[i]=1;
-			buffer = QString::null;
+			buffer = QString();
 		} else
 		if (tmp== '%'){
 			setFormat( i, 1,ColorComment);
 			state=StateGraphicComment;
 			//setFormat( i, 1,ColorVerbatim);
 			blockData->code[i]=1;
-			buffer = QString::null;
+			buffer = QString();
 		} else
 		if (tmp== '{' ){
 			blockData->code[i]=1;
@@ -918,26 +950,26 @@ while (i < text.length())
 			    setFormat(pos+4,12,ColorStandard);
 			    for (k=i-15; k <i-11 ; k++) {if (k>0 && k<text.length()) blockData->code[k]=1;}
 			}
-			buffer = QString::null;
+			buffer = QString();
 		} else
 		if (tmp== '(' ){
 			blockData->code[i]=1;
 			setFormat( i, 1,ColorVerbatim);
-			buffer = QString::null;
+			buffer = QString();
 		} else
 		if (tmp== ')' ){
 			blockData->code[i]=1;
 			setFormat( i, 1,ColorVerbatim);
-			buffer = QString::null;
+			buffer = QString();
 		} else
 		if (isWordSeparator(tmp) && tmp!='"' && tmp!='.' && tmp!='-'){
 			blockData->code[i]=1;
 			setFormat( i, 1,ColorVerbatim);
-			buffer = QString::null;
+			buffer = QString();
 		} else
 		 {
 			setFormat( i, 1,ColorVerbatim);
-			//buffer = QString::null;
+			//buffer = QString();
 		}
        } break;
        case StateGraphicAsy: {
@@ -965,7 +997,7 @@ while (i < text.length())
 			setFormat( i, 1,ColorMath);
 			blockData->code[i]=1;
 			state=StateGraphicAsyMath;
-			buffer = QString::null;
+			buffer = QString();
 // 		if (tmp=='$') {
 // 			setFormat( i, 1,ColorMath);
 // 			blockData->code[i]=1;
@@ -979,13 +1011,13 @@ while (i < text.length())
 // 					blockData->code[i]=1;
 // 					}
 // 				}
-// 			buffer = QString::null;
+// 			buffer = QString();
 		} else
 		if (tmp== '/' && next=='/'){
 			setFormat( i, 1,ColorComment);
 			state=StateGraphicAsyComment;
 			blockData->code[i]=1;
-			buffer = QString::null;
+			buffer = QString();
 		} else
 		if (tmp== '{' ){
 			blockData->code[i]=1;
@@ -1027,39 +1059,39 @@ while (i < text.length())
 			    setFormat(pos+4,12,ColorStandard);
 			    for (k=i-15; k <i-11 ; k++) {if (k>0 && k<text.length()) blockData->code[k]=1;}
 			}
-			buffer = QString::null;
+			buffer = QString();
 		} else
 		if (tmp== '(' ){
 			blockData->code[i]=1;
 			setFormat( i, 1,ColorVerbatim);
-			buffer = QString::null;
+			buffer = QString();
 		} else
 		if (tmp== ')' ){
 			blockData->code[i]=1;
 			setFormat( i, 1,ColorVerbatim);
-			buffer = QString::null;
+			buffer = QString();
 		} else
 		if (isWordSeparator(tmp) && tmp!='"' && tmp!='.' && tmp!='-'){
 			blockData->code[i]=1;
 			setFormat( i, 1,ColorVerbatim);
-			buffer = QString::null;
+			buffer = QString();
 		} else
 		 {
 			setFormat( i, 1,ColorVerbatim);
-			//buffer = QString::null;
+			//buffer = QString();
 		}
        } break;       
 	case StateGraphicComment: {
 	setFormat( i, 1,ColorComment);
 	blockData->code[i]=1;
 	state=StateGraphicComment;
-	buffer = QString::null;
+	buffer = QString();
 	} break;
 	case StateGraphicAsyComment: {
 	setFormat( i, 1,ColorComment);
 	blockData->code[i]=1;
 	state=StateGraphicAsyComment;
-	buffer = QString::null;
+	buffer = QString();
 	} break;
 	case StateGraphicCommand:{
 		tmp=text.at( i );
@@ -1143,7 +1175,6 @@ while (i < text.length())
 	} break;
 /****************************/
        case StateBib: {
-//	 qDebug() << "bib" << buffer << next;
                tmp=text.at( i );
 /*		if (tmp== '\"' ){
 			blockData->code[i]=1;
@@ -1156,14 +1187,14 @@ while (i < text.length())
 			if (next=='\n' || i == text.length()-1)
 			  {
 			  state=StateStandard;
-			  buffer = QString::null;
+			  buffer = QString();
 			  }
 		} else
 		 {
 			blockData->code[i]=1;
 			setFormat( i, 1,ColorVerbatim);
 			state=StateBib;
-			//buffer = QString::null;
+			//buffer = QString();
 		}
        } break;
 /*       case StateBibCommand: {
@@ -1225,12 +1256,12 @@ while (i < text.length())
 					blockData->code[i]=1;
 					}
 				}
-			buffer = QString::null;
+			buffer = QString();
 		} else
 		if (tmp== '%' ){
 			setFormat( i, 1,ColorVerbatim);
 			blockData->code[i]=1;
-			buffer = QString::null;
+			buffer = QString();
 		} else
 		if (tmp== '{' ){
 			blockData->code[i]=1;
@@ -1239,32 +1270,32 @@ while (i < text.length())
 		if (tmp== '}' ){
 			blockData->code[i]=1;
 			setFormat( i, 1,ColorVerbatim);
-			buffer = QString::null;
+			buffer = QString();
 		} else
 		if (tmp== '@' ){
 			blockData->code[i]=1;
 			setFormat( i, 1,ColorVerbatim);
 			state=StateStandard;
-			buffer = QString::null;
+			buffer = QString();
 		} else
 		if (tmp== '(' ){
 			blockData->code[i]=1;
 			setFormat( i, 1,ColorVerbatim);
-			buffer = QString::null;
+			buffer = QString();
 		} else
 		if (tmp== ')' ){
 			blockData->code[i]=1;
 			setFormat( i, 1,ColorVerbatim);
-			buffer = QString::null;
+			buffer = QString();
 		} else
 		if (isWordSeparator(tmp)){
 			blockData->code[i]=1;
 			setFormat( i, 1,ColorVerbatim);
-			buffer = QString::null;
+			buffer = QString();
 		} else
 		 {
 			setFormat( i, 1,ColorVerbatim);
-			//buffer = QString::null;
+			//buffer = QString();
 		}
        } break;
 	case StateSweaveCommand:{
@@ -1414,7 +1445,7 @@ if (state == StateComment)
 	i=0;
 	while (i < text.length())
 		{
-		buffer = QString::null;
+		buffer = QString();
 		ch = text.at( i );
 		while (!isSpace(ch) || ch=='%')
 		      {
@@ -1438,26 +1469,32 @@ if (state == StateComment)
 
 if (state == StateGraphic || state == StateGraphicCommand || state == StateGraphicComment || state == StateGraphicAsy || state == StateGraphicAsyCommand || state == StateGraphicAsyComment)
 {
-	QRegExp number("[0-9]*\\.?[0-9]+([eE][-+]?[0-9]+)?");
-	int index = number.indexIn(text);
+	QRegularExpression number("[0-9]*\\.?[0-9]+([eE][-+]?[0-9]+)?");
+	//int index = number.indexIn(text);
+    int index=number.match(text).capturedStart();
         while (index >= 0) {
-            int length = number.matchedLength();
+            //int length = number.matchedLength();
+            int length=number.match(text).capturedLength();
             if (blockData->code[index]!=1) setFormat(index, length, ColorNumberGraphic);
-            index = number.indexIn(text, index + length);
+            //index = number.indexIn(text, index + length);
+            index=number.match(text,index+length).capturedStart();
         }
 	if (state == StateGraphicAsy || state == StateGraphicAsyCommand || state == StateGraphicAsyComment)
 	{
-		QRegExp expression("\\b[A-Za-z0-9_]+(?=\\()");
-		index = expression.indexIn(text);
+		QRegularExpression expression("\\b[A-Za-z0-9_]+(?=\\()");
+		//index = expression.indexIn(text);
+        index=expression.match(text).capturedStart();
 		while (index >= 0) {
-		    int length = expression.matchedLength();
+		    //int length = expression.matchedLength();
+            int length=expression.match(text).capturedLength();
 		    if (blockData->code[index]!=1) setFormat(index, length, ColorKeyword);
-		    index = expression.indexIn(text, index + length);
+		    //index = expression.indexIn(text, index + length);
+            index=expression.match(text,index+length).capturedStart();
 		}
 	i=0;
 	while (i < text.length())
 		{
-		buffer = QString::null;
+		buffer = QString();
 		ch = text.at( i );
 		while ((blockData->code[i]!=1 || ch=='\\') && (!isSpace(ch)))
 		      {
@@ -1489,12 +1526,15 @@ if (state == StateGraphic || state == StateGraphicCommand || state == StateGraph
 	}
 	else if ((text.indexOf("pspicture") == -1) && (text.indexOf("tikzpicture") == -1))
 	{
-		QRegExp expression("\\\\[A-Za-z]+");
-		index = expression.indexIn(text);
+		QRegularExpression expression("\\\\[A-Za-z]+");
+		//index = expression.indexIn(text);
+        index=expression.match(text).capturedStart();
 		while (index >= 0) {
-		    int length = expression.matchedLength();
+		    //int length = expression.matchedLength();
+            int length=expression.match(text).capturedLength();
 		    if ((format(index).foreground()!=brushmath) && (format(index).foreground()!=brushcomment)) setFormat(index, length, ColorKeywordGraphic);
-		    index = expression.indexIn(text, index + length);
+		    //index = expression.indexIn(text, index + length);
+            index=expression.match(text,index+length).capturedStart();
 		}	  
 	}
 
@@ -1506,11 +1546,12 @@ if (pChecker && state!=StateGraphic && state!=StateGraphicCommand && state!=Stat
 	int check;
 	int offset ;
 	QTextCodec *codec = QTextCodec::codecForName(spell_encoding.toLatin1());
+    if(!codec) codec = QTextCodec::codecForLocale();
 	QByteArray encodedString;
 
 	while (i < text.length())
 		{
-		buffer = QString::null;
+		buffer = QString();
 		ch = text.at( i );
 		offset=0;
 		while ((blockData->code[i]!=1) && (!isSpace(ch)))
@@ -1611,7 +1652,7 @@ while (i < text.length())
 			blockData->code[i]=1;
 			state=StateGraphicMath;
 			}
-	buffer = QString::null;
+	buffer = QString();
 	} break;
 
        case StateGraphic: {
@@ -1639,7 +1680,7 @@ while (i < text.length())
 			setFormat( i, 1,ColorMath);
 			blockData->code[i]=1;
 			state=StateGraphicMath;
-			buffer = QString::null;
+			buffer = QString();
 // 		if (tmp=='$') {
 // 			setFormat( i, 1,ColorMath);
 // 			blockData->code[i]=1;
@@ -1653,19 +1694,19 @@ while (i < text.length())
 // 					blockData->code[i]=1;
 // 					}
 // 				}
-// 			buffer = QString::null;
+// 			buffer = QString();
 		} else
 		if (tmp== '/' && next=='/'){
 			setFormat( i, 1,ColorComment);
 			state=StateGraphicComment;
 			blockData->code[i]=1;
-			buffer = QString::null;
+			buffer = QString();
 // 		} else
 // 		if (tmp== '%' ){
 // 			setFormat( i, 1,ColorComment);
 // 			state=StateGraphicComment;
 // 			blockData->code[i]=1;
-// 			buffer = QString::null;
+// 			buffer = QString();
 		} else
 		if (tmp== '{' ){
 			blockData->code[i]=1;
@@ -1675,26 +1716,26 @@ while (i < text.length())
 		  	blockData->code[i]=1;
 			setFormat( i, 1,ColorStandard);
 			state=StateGraphic;
-			buffer = QString::null;
+			buffer = QString();
 		} else
 		if (tmp== '(' ){
 			blockData->code[i]=1;
 			setFormat( i, 1,ColorStandard);
-			buffer = QString::null;
+			buffer = QString();
 		} else
 		if (tmp== ')' ){
 			blockData->code[i]=1;
 			setFormat( i, 1,ColorStandard);
-			buffer = QString::null;
+			buffer = QString();
 		} else
 		if (isWordSeparator(tmp) && tmp!='"' && tmp!='.'  && tmp!='-'){
 			blockData->code[i]=1;
 			setFormat( i, 1,ColorStandard);
-			buffer = QString::null;
+			buffer = QString();
 		} else
 		 {
 			setFormat( i, 1,ColorStandard);
-			//buffer = QString::null;
+			//buffer = QString();
 		}
        } break;
        
@@ -1702,7 +1743,7 @@ while (i < text.length())
 	setFormat( i, 1,ColorComment);
 	blockData->code[i]=1;
 	state=StateGraphicComment;
-	buffer = QString::null;
+	buffer = QString();
 	} break;
 	
 	case StateGraphicCommand:{
@@ -1775,25 +1816,31 @@ else
 if (text.isEmpty()) return;
 if (state == StateGraphic || state == StateGraphicCommand || state == StateGraphicComment)
 {
-	QRegExp number("[0-9]*\\.?[0-9]+([eE][-+]?[0-9]+)?");
-	int index = number.indexIn(text);
+	QRegularExpression number("[0-9]*\\.?[0-9]+([eE][-+]?[0-9]+)?");
+	//int index = number.indexIn(text);
+    int index=number.match(text).capturedStart();
         while (index >= 0) {
-            int length = number.matchedLength();
+            //int length = number.matchedLength();
+            int length=number.match(text).capturedLength();
             if (blockData->code[index]!=1) setFormat(index, length, ColorNumberGraphic);
-            index = number.indexIn(text, index + length);
+            //index = number.indexIn(text, index + length);
+            index=number.match(text,index+length).capturedStart();
         }
-	QRegExp expression("\\b[A-Za-z0-9_]+(?=\\()");
-	index = expression.indexIn(text);
+	QRegularExpression expression("\\b[A-Za-z0-9_]+(?=\\()");
+	//index = expression.indexIn(text);
+    index=expression.match(text).capturedStart();
         while (index >= 0) {
-            int length = expression.matchedLength();
+            //int length = expression.matchedLength();
+            int length=expression.match(text).capturedLength();
             if (blockData->code[index]!=1) setFormat(index, length, ColorKeyword);
-            index = expression.indexIn(text, index + length);
+            //index = expression.indexIn(text, index + length);
+            index=expression.match(text,index+length).capturedStart();
         }
 
 	i=0;
 	while (i < text.length())
 		{
-		buffer = QString::null;
+		buffer = QString();
 		ch = text.at( i );
 		while ((blockData->code[i]!=1 || ch=='\\') && (!isSpace(ch)))
 		      {
