@@ -1,14 +1,13 @@
 /***************************************************************************
- *   copyright       : (C) 2003-2017 by Pascal Brachet                     *
- *   http://www.xm1math.net/texmaker/                                      *
- *   addons by Luis Silvestre                                              *
- *   contains some code from CLedit (C) 2010 Heinz van Saanen -GPL         *
+ *   copyright       : (C) 2003-2023 by Pascal Brachet                     *
+ *   https://www.xm1math.net/texmaker/                                     *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   @license GPL-2.0+ <https://spdx.org/licenses/GPL-2.0+.html>           *
  ***************************************************************************/
 
 #include "lightlatexeditor.h"
@@ -29,14 +28,17 @@
 #include <QModelIndex>
 #include <QAbstractItemModel>
 #include <QScrollBar>
-#include <QTextCodec>
 #include <QFile>
 #include <QFileInfo>
-#include <QTextCodec>
 #include <QFileInfo>
 #include <QMessageBox>
 #include <QLineEdit>
 #include <QTextDocumentFragment>
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+    #include <QtCore/QTextCodec>
+#else
+    #include <QtCore5Compat/QTextCodec>
+#endif
 
 #include "blockdata.h"
 #include "encodingdialog.h"
@@ -96,7 +98,11 @@ setFrameShape(QFrame::NoFrame);
 for (int i = 0; i < 3; ++i) UserBookmark[i]=0;
 encoding="";
 setFont(efont);
+#if QT_VERSION < QT_VERSION_CHECK(5, 11, 0)
 setTabStopWidth(fontMetrics().width("    "));
+#else
+setTabStopDistance(fontMetrics().horizontalAdvance("    "));
+#endif
 setTabChangesFocus(false);
 endBlock=-1;
 lastnumlines=0;
@@ -140,7 +146,7 @@ update();
 
 bool LightLatexEditor::search( const QString &expr, bool cs, bool wo, bool forward, bool startAtCursor, bool isRegExp)
 {
-QTextDocument::FindFlags flags = 0;
+QTextDocument::FindFlags flags = QTextDocument::FindFlags(0);
 if (cs) flags |= QTextDocument::FindCaseSensitively;
 if (wo) flags |= QTextDocument::FindWholeWords;
 QTextCursor c = textCursor();
@@ -158,7 +164,7 @@ if (! startAtCursor)
 	setTextCursor(c);
 	}
 if (forward == false) flags |= QTextDocument::FindBackward;
-QTextCursor found = isRegExp?document()->find(QRegExp(expr), c, flags) : document()->find(expr, c, flags);
+QTextCursor found = isRegExp?document()->find(QRegularExpression(expr), c, flags) : document()->find(expr, c, flags);
 
 if (found.isNull()) return false;
 else 
@@ -170,11 +176,11 @@ else
 
 int LightLatexEditor::searchInSelection( const QString &expr, bool cs, bool wo, bool isRegExp, int start, int end)
 {
-QTextDocument::FindFlags flags = 0;
+QTextDocument::FindFlags flags = QTextDocument::FindFlags(0);
 if (cs) flags |= QTextDocument::FindCaseSensitively;
 if (wo) flags |= QTextDocument::FindWholeWords;
 
-QTextCursor found = isRegExp?document()->find(QRegExp(expr), start, flags) : document()->find(expr, start, flags);
+QTextCursor found = isRegExp?document()->find(QRegularExpression(expr), start, flags) : document()->find(expr, start, flags);
 
 if (found.isNull()) return -1;
 else 
@@ -743,7 +749,11 @@ if (inBlockSelectionMode
 	&& block.position() >= blockSelection.firstBlock.block().position()
 	&& block.position() <= blockSelection.lastBlock.block().position()) {
     QString text = block.text();
+    #if QT_VERSION < QT_VERSION_CHECK(5, 11, 0)
     qreal spacew = QFontMetricsF(font()).width(QLatin1Char(' '));
+    #else
+    qreal spacew = QFontMetricsF(font()).horizontalAdvance(QLatin1Char(' '));
+    #endif
 
     int offset = 0;
     int relativePos  =  blockSelection.positionAtColumn(text, blockSelection.firstVisualColumn, &offset);
@@ -806,15 +816,22 @@ if (inBlockSelectionMode
                     w = line.cursorToX(relativePos + 1) - x;
                     if (doc->characterAt(context.cursorPosition) == QLatin1Char('\t')) {
                         doSelection = false;
-                        qreal space = QFontMetricsF(layout->font()).width(QLatin1Char(' '));
+                            #if QT_VERSION < QT_VERSION_CHECK(5, 11, 0)
+                            qreal space = QFontMetricsF(layout->font()).width(QLatin1Char(' '));
+                            #else
+                            qreal space = QFontMetricsF(layout->font()).horizontalAdvance(QLatin1Char(' '));
+                            #endif
                         if (w > space) {
                             x += w-space;
                             w = space;
                         }
                     }
                 } else
-                    w = QFontMetrics(layout->font()).width(QLatin1Char(' ')); // in sync with QTextLine::draw()
-
+                            #if QT_VERSION < QT_VERSION_CHECK(5, 11, 0)
+                            w = QFontMetrics(layout->font()).width(QLatin1Char(' ')); // in sync with QTextLine::draw()
+                            #else
+                            w = QFontMetrics(layout->font()).horizontalAdvance(QLatin1Char(' ')); // in sync with QTextLine::draw()
+                            #endif
                 QRectF rr = line.rect();
                 rr.moveTop(rr.top() + r.top());
                 rr.moveLeft(r.left() + x);
@@ -864,7 +881,7 @@ block = block.next();
 
     if (backgroundVisible() && !block.isValid() && offset.y() <= er.bottom()
         && (centerOnScroll() || verticalScrollBar()->maximum() == verticalScrollBar()->minimum())) {
-        painter.fillRect(QRect(QPoint((int)er.left(), (int)offset.y()), er.bottomRight()), palette().background());
+        painter.fillRect(QRect(QPoint((int)er.left(), (int)offset.y()), er.bottomRight()), palette().window());
     }
     
 
@@ -955,7 +972,11 @@ if (e->modifiers() & Qt::AltModifier)
 	// get visual column
 	int column = blockSelection.columnAt(cursor.block().text(), cursor.positionInBlock());
 	if (cursor.positionInBlock() == cursor.block().length()-1) {
+        #if QT_VERSION < QT_VERSION_CHECK(5, 11, 0)
 	    column += (e->pos().x() - cursorRect().center().x())/QFontMetricsF(font()).width(QLatin1Char(' '));
+        #else
+        column += (e->pos().x() - cursorRect().center().x())/QFontMetricsF(font()).horizontalAdvance(QLatin1Char(' '));
+        #endif
 	}
 	  blockSelection.moveAnchor(cursor.blockNumber(), column);
 	setTextCursor(blockSelection.selection());
@@ -1055,7 +1076,7 @@ QMimeData *LightLatexEditor::createMimeDataFromSelection() const
             const int endOfDocument = tempDocument->characterCount() - 1;
             for (QTextBlock current = start; current.isValid() && current != end; current = current.next()) {
                 const QTextLayout *layout = current.layout();
-                foreach (const QTextLayout::FormatRange &range, layout->additionalFormats()) {
+                foreach (const QTextLayout::FormatRange &range, layout->formats()) {
                     const int start = current.position() + range.start - selectionStart;
                     const int end = start + range.length;
                     if (end <= 0 || start >= endOfDocument)
