@@ -1,16 +1,18 @@
 /***************************************************************************
- *   copyright       : (C) 2003-2017 by Pascal Brachet                     *
- *   http://www.xm1math.net/texmaker/                                      *
+ *   copyright       : (C) 2003-2023 by Pascal Brachet                     *
+ *   https://www.xm1math.net/texmaker/                                     *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   @license GPL-2.0+ <https://spdx.org/licenses/GPL-2.0+.html>           *
  ***************************************************************************/
 
 
 #include <QtGui>
+#include <QRegularExpression>
 
 #include "lightlatexhighlighter.h"
 #include "lightlatexeditor.h"
@@ -58,7 +60,7 @@ rehighlight();
 
 void LightLatexHighlighter::highlightBlock(const QString &text)
 {
-QRegExp rxSweave("<<(.*)>>=");
+QRegularExpression rxSweave("<<(.*)>>=");
 QStringList types;
 types << QLatin1String("article") << QLatin1String("book")
   << QLatin1String("booklet") << QLatin1String("inbook")
@@ -72,8 +74,7 @@ types << QLatin1String("article") << QLatin1String("book")
   << QLatin1String("online") << QLatin1String("mvproceedings")
   << QLatin1String("inproceedings") << QLatin1String("report")
   << QLatin1String("thesis") << QLatin1String("electronic") << QLatin1String("patent");
-QRegExp rxBib("@("+types.join("|")+")\\s*\\{\\s*(.*),", Qt::CaseInsensitive);
-rxBib.setMinimal(true);
+QRegularExpression rxBib("@("+types.join("|")+")\\s*\\{\\s*(.*),", QRegularExpression::CaseInsensitiveOption | QRegularExpression::InvertedGreedinessOption);
 
 const int StateStandard = 0;
 const int StateComment = 1;
@@ -130,8 +131,13 @@ setCurrentBlockUserData(blockData);
 /////////////////////
 
 /////////////////
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
 QRegExp rxverb("verb\\*?([^\\*])");
 QRegExp rxlst("lstinline(.)");
+#else
+QRegularExpression rxverb(QRegularExpression::anchoredPattern("verb\\*?([^\\*])"));
+QRegularExpression rxlst(QRegularExpression::anchoredPattern("lstinline(.)"));
+#endif
 QTextCharFormat structFormat;
 structFormat.setFontWeight(QFont::Bold);
 structFormat.setForeground(ColorKeyword);
@@ -175,7 +181,7 @@ while (i < text.length())
 			blockData->code[i]=1;
 			state=StateCommand;
 			}
-			buffer = QString::null;
+			buffer = QString();
 		} else
 		if (tmp=='$') {
 			setFormat( i, 1,ColorMath);
@@ -190,13 +196,13 @@ while (i < text.length())
 					blockData->code[i]=1;
 					}
 				}
-			buffer = QString::null;
+			buffer = QString();
 		} else
 		if (tmp== '%' ){
 			setFormat( i, 1,ColorComment);
 			state=StateComment;
 			blockData->code[i]=1;
-			buffer = QString::null;
+			buffer = QString();
 		} else
 		if (tmp== '{' ){
 			blockData->code[i]=1;
@@ -244,7 +250,7 @@ while (i < text.length())
 			if(poslab != -1) {state=StateMath;for (k=poslab; k <i ; k++) {if (k>0 && k<text.length()) blockData->code[k]=1;}}
 			poslab=buffer.indexOf("begin{gather*}") ;
 			if(poslab != -1) {state=StateMath;for (k=poslab; k <i ; k++) {if (k>0 && k<text.length()) blockData->code[k]=1;}}
-			buffer = QString::null;
+			buffer = QString();
 		} else
 		if (tmp== '<' ){
 			blockData->code[i]=1;
@@ -267,44 +273,44 @@ while (i < text.length())
 			  if ((posbib2 !=-1) && (posbib2>posbib)) setFormat(posbib,posbib2-posbib,structFormat);
 			  for (k=posbib; k <i ; k++) {if (k>0 && k<text.length()) blockData->code[k]=1;}
 			  state=StateBib;
-			  buffer = QString::null;
+			  buffer = QString();
 			  }
 		} else
 		if (tmp== '=' ){
 			blockData->code[i]=1;
 			setFormat( i, 1,ColorStandard);
-			if(buffer.indexOf(rxSweave) != -1) {state=StateSweave;buffer = QString::null;}
+			if(buffer.indexOf(rxSweave) != -1) {state=StateSweave;buffer = QString();}
 		} else
 		if (tmp== '(' ){
 			blockData->code[i]=1;
 			setFormat( i, 1,ColorStandard);
 			state=StateStandard;
-			buffer = QString::null;
+			buffer = QString();
 		} else
 		if (tmp== ')' ){
 			blockData->code[i]=1;
 			setFormat( i, 1,ColorStandard);
 			state=StateStandard;
-			buffer = QString::null;
+			buffer = QString();
 		} else
 		if (isWordSeparator(tmp)){
 			blockData->code[i]=1;
 			setFormat( i, 1,ColorStandard);
-			//buffer = QString::null;
+			//buffer = QString();
 		} else
 		 {
 			setFormat( i, 1,ColorStandard);
 			state=StateStandard;
-			//buffer = QString::null;
+			//buffer = QString();
 		}
-//	buffer = QString::null;
+//	buffer = QString();
 	} break;
 	
 	case StateComment: {
 	setFormat( i, 1,ColorComment);
 	blockData->code[i]=1;
 	state=StateComment;
-	buffer = QString::null;
+	buffer = QString();
 	} break;
 
 	case StateMath: {
@@ -322,7 +328,7 @@ while (i < text.length())
 					blockData->code[i]=1;
 					}
 				}
-		buffer = QString::null;
+		buffer = QString();
 		} else if (tmp== '\\') {
 			if (next==']' || next==')')
 				{
@@ -335,7 +341,7 @@ while (i < text.length())
 					setFormat( i, 1,ColorMath);
 					blockData->code[i]=1;
 					}
-				buffer = QString::null;
+				buffer = QString();
 				}
 			else if (next=='$')
 				{
@@ -430,7 +436,7 @@ while (i < text.length())
 			    setFormat(pos+4,9,ColorStandard);
 			    for (k=i-12; k <i-8 ; k++) {if (k>0 && k<text.length()) blockData->code[k]=1;}
 			}
-		buffer = QString::null;
+		buffer = QString();
 		} else
 		 {
 			setFormat( i, 1,ColorMath);
@@ -479,7 +485,7 @@ while (i < text.length())
 			blockData->code[i]=1;
 			state=StateGraphicMath;
 			}
-	buffer = QString::null;
+	buffer = QString();
 	} break;
 	case StateGraphicAsyMath: {
 		tmp=text.at( i );
@@ -525,20 +531,38 @@ while (i < text.length())
 			blockData->code[i]=1;
 			state=StateGraphicAsyMath;
 			}
-	buffer = QString::null;
+	buffer = QString();
 	} break;
 	case StateCommand:{
 		tmp=text.at( i );
-		if (rxverb.exactMatch(buffer))
+        #if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
+        if (rxverb.exactMatch(buffer))
+        #else
+        QRegularExpressionMatch rxverbMatch=rxverb.match(buffer);
+        QRegularExpressionMatch rxlstMatch=rxlst.match(buffer);
+        if (rxverbMatch.hasMatch())
+        #endif
 				{
-				 verbflag=rxverb.cap(1).at(0);
+                #if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
+                verbflag=rxverb.cap(1).at(0);
+                #else
+				 verbflag=rxverbMatch.captured(1).at(0);
+                #endif
 				 blockData->code[i]=1;
 				 setFormat( i, 1,ColorCommand);
 				 state=StateVerbatim;
 		} else
-		if (rxlst.exactMatch(buffer))
+        #if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
+        if (rxlst.exactMatch(buffer))
+        #else
+		if (rxlstMatch.hasMatch())
+        #endif
 				{
-				 verbflag=rxlst.cap(1).at(0);
+                #if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
+                if (rxlst.exactMatch(buffer))
+                #else
+				 verbflag=rxlstMatch.captured(1).at(0);
+                #endif
 				 blockData->code[i]=1;
 				 setFormat( i, 1,ColorCommand);
 				 state=StateVerbatim;
@@ -656,12 +680,12 @@ while (i < text.length())
 					blockData->code[i]=1;
 					}
 				}
-			buffer = QString::null;
+			buffer = QString();
 		} else
 		if (tmp== '%' ){
 			setFormat( i, 1,ColorVerbatim);
 			blockData->code[i]=1;
-			buffer = QString::null;
+			buffer = QString();
 		} else
 		if (tmp== '{' ){
 			blockData->code[i]=1;
@@ -703,26 +727,26 @@ while (i < text.length())
 			    setFormat(pos+4,9,ColorStandard);
 			    for (k=i-12; k <i-8 ; k++) {if (k>0 && k<text.length()) blockData->code[k]=1;}
 			}
-			buffer = QString::null;
+			buffer = QString();
 		} else
 		if (tmp== '(' ){
 			blockData->code[i]=1;
 			setFormat( i, 1,ColorVerbatim);
-			buffer = QString::null;
+			buffer = QString();
 		} else
 		if (tmp== ')' ){
 			blockData->code[i]=1;
 			setFormat( i, 1,ColorVerbatim);
-			buffer = QString::null;
+			buffer = QString();
 		} else
 		if (isWordSeparator(tmp)){
 			blockData->code[i]=1;
 			setFormat( i, 1,ColorVerbatim);
-			buffer = QString::null;
+			buffer = QString();
 		} else
 		 {
 			setFormat( i, 1,ColorVerbatim);
-			//buffer = QString::null;
+			//buffer = QString();
 		}
        } break;
 	case StateVerbatimCommand:{
@@ -806,19 +830,19 @@ while (i < text.length())
 					blockData->code[i]=1;
 					}
 				}
-			buffer = QString::null;
+			buffer = QString();
 		} else
 		if (tmp== '/' && next=='/'){
 			setFormat( i, 1,ColorComment);
 			state=StateGraphicComment;
 			blockData->code[i]=1;
-			buffer = QString::null;
+			buffer = QString();
 		} else
 		if (tmp== '%' ){
 			setFormat( i, 1,ColorComment);
 			state=StateGraphicComment;
 			blockData->code[i]=1;
-			buffer = QString::null;
+			buffer = QString();
 		} else
 		if (tmp== '{' ){
 			blockData->code[i]=1;
@@ -860,26 +884,26 @@ while (i < text.length())
 			    setFormat(pos+4,12,ColorStandard);
 			    for (k=i-15; k <i-11 ; k++) {if (k>0 && k<text.length()) blockData->code[k]=1;}
 			}
-			buffer = QString::null;
+			buffer = QString();
 		} else
 		if (tmp== '(' ){
 			blockData->code[i]=1;
 			setFormat( i, 1,ColorVerbatim);
-			buffer = QString::null;
+			buffer = QString();
 		} else
 		if (tmp== ')' ){
 			blockData->code[i]=1;
 			setFormat( i, 1,ColorVerbatim);
-			buffer = QString::null;
+			buffer = QString();
 		} else
 		if (isWordSeparator(tmp) && tmp!='"' && tmp!='.'  && tmp!='-'){
 			blockData->code[i]=1;
 			setFormat( i, 1,ColorVerbatim);
-			buffer = QString::null;
+			buffer = QString();
 		} else
 		 {
 			setFormat( i, 1,ColorVerbatim);
-			//buffer = QString::null;
+			//buffer = QString();
 		}
        } break;
        case StateGraphicAsy: {
@@ -907,7 +931,7 @@ while (i < text.length())
 			setFormat( i, 1,ColorMath);
 			blockData->code[i]=1;
 			state=StateGraphicAsyMath;
-			buffer = QString::null;
+			buffer = QString();
 // 		if (tmp=='$') {
 // 			setFormat( i, 1,ColorMath);
 // 			blockData->code[i]=1;
@@ -921,13 +945,13 @@ while (i < text.length())
 // 					blockData->code[i]=1;
 // 					}
 // 				}
-// 			buffer = QString::null;
+// 			buffer = QString();
 		} else
 		if (tmp== '/' && next=='/'){
 			setFormat( i, 1,ColorComment);
 			state=StateGraphicAsyComment;
 			blockData->code[i]=1;
-			buffer = QString::null;
+			buffer = QString();
 		} else
 		if (tmp== '{' ){
 			blockData->code[i]=1;
@@ -969,39 +993,39 @@ while (i < text.length())
 			    setFormat(pos+4,12,ColorStandard);
 			    for (k=i-15; k <i-11 ; k++) {if (k>0 && k<text.length()) blockData->code[k]=1;}
 			}
-			buffer = QString::null;
+			buffer = QString();
 		} else
 		if (tmp== '(' ){
 			blockData->code[i]=1;
 			setFormat( i, 1,ColorVerbatim);
-			buffer = QString::null;
+			buffer = QString();
 		} else
 		if (tmp== ')' ){
 			blockData->code[i]=1;
 			setFormat( i, 1,ColorVerbatim);
-			buffer = QString::null;
+			buffer = QString();
 		} else
 		if (isWordSeparator(tmp) && tmp!='"' && tmp!='.'  && tmp!='-'){
 			blockData->code[i]=1;
 			setFormat( i, 1,ColorVerbatim);
-			buffer = QString::null;
+			buffer = QString();
 		} else
 		 {
 			setFormat( i, 1,ColorVerbatim);
-			//buffer = QString::null;
+			//buffer = QString();
 		}
        } break;       
 	case StateGraphicComment: {
 	setFormat( i, 1,ColorComment);
 	blockData->code[i]=1;
 	state=StateGraphicComment;
-	buffer = QString::null;
+	buffer = QString();
 	} break;
 	case StateGraphicAsyComment: {
 	setFormat( i, 1,ColorComment);
 	blockData->code[i]=1;
 	state=StateGraphicAsyComment;
-	buffer = QString::null;
+	buffer = QString();
 	} break;
 	case StateGraphicCommand:{
 		tmp=text.at( i );
@@ -1085,7 +1109,6 @@ while (i < text.length())
 	} break;
 /****************************/
        case StateBib: {
-//	 qDebug() << "bib" << buffer << next;
                tmp=text.at( i );
 /*		if (tmp== '\"' ){
 			blockData->code[i]=1;
@@ -1098,14 +1121,14 @@ while (i < text.length())
 			if (next=='\n' || i == text.length()-1)
 			  {
 			  state=StateStandard;
-			  buffer = QString::null;
+			  buffer = QString();
 			  }
 		} else
 		 {
 			blockData->code[i]=1;
 			setFormat( i, 1,ColorVerbatim);
 			state=StateBib;
-			//buffer = QString::null;
+			//buffer = QString();
 		}
        } break;
 /*       case StateBibCommand: {
@@ -1167,12 +1190,12 @@ while (i < text.length())
 					blockData->code[i]=1;
 					}
 				}
-			buffer = QString::null;
+			buffer = QString();
 		} else
 		if (tmp== '%' ){
 			setFormat( i, 1,ColorVerbatim);
 			blockData->code[i]=1;
-			buffer = QString::null;
+			buffer = QString();
 		} else
 		if (tmp== '{' ){
 			blockData->code[i]=1;
@@ -1181,32 +1204,32 @@ while (i < text.length())
 		if (tmp== '}' ){
 			blockData->code[i]=1;
 			setFormat( i, 1,ColorVerbatim);
-			buffer = QString::null;
+			buffer = QString();
 		} else
 		if (tmp== '@' ){
 			blockData->code[i]=1;
 			setFormat( i, 1,ColorVerbatim);
 			state=StateStandard;
-			buffer = QString::null;
+			buffer = QString();
 		} else
 		if (tmp== '(' ){
 			blockData->code[i]=1;
 			setFormat( i, 1,ColorVerbatim);
-			buffer = QString::null;
+			buffer = QString();
 		} else
 		if (tmp== ')' ){
 			blockData->code[i]=1;
 			setFormat( i, 1,ColorVerbatim);
-			buffer = QString::null;
+			buffer = QString();
 		} else
 		if (isWordSeparator(tmp)){
 			blockData->code[i]=1;
 			setFormat( i, 1,ColorVerbatim);
-			buffer = QString::null;
+			buffer = QString();
 		} else
 		 {
 			setFormat( i, 1,ColorVerbatim);
-			//buffer = QString::null;
+			//buffer = QString();
 		}
        } break;
 	case StateSweaveCommand:{
@@ -1333,7 +1356,7 @@ if (state == StateComment)
 	i=0;
 	while (i < text.length())
 		{
-		buffer = QString::null;
+		buffer = QString();
 		ch = text.at( i );
 		while (!isSpace(ch) || ch=='%')
 		      {
@@ -1357,26 +1380,32 @@ if (state == StateComment)
 
 if (state == StateGraphic || state == StateGraphicCommand || state == StateGraphicComment || state == StateGraphicAsy || state == StateGraphicAsyCommand || state == StateGraphicAsyComment)
 {
-	QRegExp number("[0-9]*\\.?[0-9]+([eE][-+]?[0-9]+)?");
-	int index = number.indexIn(text);
+	QRegularExpression number("[0-9]*\\.?[0-9]+([eE][-+]?[0-9]+)?");
+	//int index = number.indexIn(text);
+    int index=number.match(text).capturedStart();
         while (index >= 0) {
-            int length = number.matchedLength();
+            //int length = number.matchedLength();
+            int length=number.match(text).capturedLength();
             if (blockData->code[index]!=1) setFormat(index, length, ColorNumberGraphic);
-            index = number.indexIn(text, index + length);
+            //index = number.indexIn(text, index + length);
+            index=number.match(text,index+length).capturedStart();
         }
 	if (state == StateGraphicAsy || state == StateGraphicAsyCommand || state == StateGraphicAsyComment)
 	{
-		QRegExp expression("\\b[A-Za-z0-9_]+(?=\\()");
-		index = expression.indexIn(text);
+		QRegularExpression expression("\\b[A-Za-z0-9_]+(?=\\()");
+		//index = expression.indexIn(text);
+        index=expression.match(text).capturedStart();
 		while (index >= 0) {
-		    int length = expression.matchedLength();
+		    //int length = expression.matchedLength();
+            int length=expression.match(text).capturedLength();
 		    if (blockData->code[index]!=1) setFormat(index, length, ColorKeyword);
-		    index = expression.indexIn(text, index + length);
+		    //index = expression.indexIn(text, index + length);
+            index=expression.match(text,index+length).capturedStart();
 		}
 	i=0;
 	while (i < text.length())
 		{
-		buffer = QString::null;
+		buffer = QString();
 		ch = text.at( i );
 		while ((blockData->code[i]!=1 || ch=='\\') && (!isSpace(ch)))
 		      {
@@ -1407,13 +1436,16 @@ if (state == StateGraphic || state == StateGraphicCommand || state == StateGraph
 	}
 	else if ((text.indexOf("pspicture") == -1) && (text.indexOf("tikzpicture") == -1))
 	{
-		QRegExp expression("\\\\[A-Za-z]+");
-		index = expression.indexIn(text);
+		QRegularExpression expression("\\\\[A-Za-z]+");
+		//index = expression.indexIn(text);
+        index=expression.match(text).capturedStart();
 		while (index >= 0) {
-		    int length = expression.matchedLength();
+		    //int length = expression.matchedLength();
+            int length=expression.match(text).capturedLength();
 		    if ((format(index).foreground()!=brushmath) && (format(index).foreground()!=brushcomment)) setFormat(index, length, ColorKeywordGraphic);
-		    index = expression.indexIn(text, index + length);
-		}	  
+		    //index = expression.indexIn(text, index + length);
+            index=expression.match(text,index+length).capturedStart();
+		}
 	}
 
 }
@@ -1479,7 +1511,7 @@ while (i < text.length())
 			blockData->code[i]=1;
 			state=StateGraphicMath;
 		}
-	buffer = QString::null;
+	buffer = QString();
 	} break;
 
        case StateGraphic: {
@@ -1507,7 +1539,7 @@ while (i < text.length())
 			setFormat( i, 1,ColorMath);
 			blockData->code[i]=1;
 			state=StateGraphicMath;
-			buffer = QString::null;
+			buffer = QString();
 // 		if (tmp=='$') {
 // 			setFormat( i, 1,ColorMath);
 // 			blockData->code[i]=1;
@@ -1521,19 +1553,19 @@ while (i < text.length())
 // 					blockData->code[i]=1;
 // 					}
 // 				}
-// 			buffer = QString::null;
+// 			buffer = QString();
 		} else
 		if (tmp== '/' && next=='/'){
 			setFormat( i, 1,ColorComment);
 			state=StateGraphicComment;
 			blockData->code[i]=1;
-			buffer = QString::null;
+			buffer = QString();
 // 		} else
 // 		if (tmp== '%' ){
 // 			setFormat( i, 1,ColorComment);
 // 			state=StateGraphicComment;
 // 			blockData->code[i]=1;
-// 			buffer = QString::null;
+// 			buffer = QString();
 		} else
 		if (tmp== '{' ){
 			blockData->code[i]=1;
@@ -1543,26 +1575,26 @@ while (i < text.length())
 		  	blockData->code[i]=1;
 			setFormat( i, 1,ColorStandard);
 			state=StateGraphic;
-			buffer = QString::null;
+			buffer = QString();
 		} else
 		if (tmp== '(' ){
 			blockData->code[i]=1;
 			setFormat( i, 1,ColorStandard);
-			buffer = QString::null;
+			buffer = QString();
 		} else
 		if (tmp== ')' ){
 			blockData->code[i]=1;
 			setFormat( i, 1,ColorStandard);
-			buffer = QString::null;
+			buffer = QString();
 		} else
 		if (isWordSeparator(tmp) && tmp!='"' && tmp!='.'  && tmp!='-'){
 			blockData->code[i]=1;
 			setFormat( i, 1,ColorStandard);
-			buffer = QString::null;
+			buffer = QString();
 		} else
 		 {
 			setFormat( i, 1,ColorStandard);
-			//buffer = QString::null;
+			//buffer = QString();
 		}
        } break;
        
@@ -1570,7 +1602,7 @@ while (i < text.length())
 	setFormat( i, 1,ColorComment);
 	blockData->code[i]=1;
 	state=StateGraphicComment;
-	buffer = QString::null;
+	buffer = QString();
 	} break;
 	
 	case StateGraphicCommand:{
@@ -1643,25 +1675,31 @@ else
 if (text.isEmpty()) return;
 if (state == StateGraphic || state == StateGraphicCommand || state == StateGraphicComment)
 {
-	QRegExp number("[0-9]*\\.?[0-9]+([eE][-+]?[0-9]+)?");
-	int index = number.indexIn(text);
+	QRegularExpression number("[0-9]*\\.?[0-9]+([eE][-+]?[0-9]+)?");
+	//int index = number.indexIn(text);
+    int index=number.match(text).capturedStart();
         while (index >= 0) {
-            int length = number.matchedLength();
+            //int length = number.matchedLength();
+            int length=number.match(text).capturedLength();
             if (blockData->code[index]!=1) setFormat(index, length, ColorNumberGraphic);
-            index = number.indexIn(text, index + length);
+            //index = number.indexIn(text, index + length);
+            index=number.match(text,index+length).capturedStart();
         }
-	QRegExp expression("\\b[A-Za-z0-9_]+(?=\\()");
-	index = expression.indexIn(text);
+	QRegularExpression expression("\\b[A-Za-z0-9_]+(?=\\()");
+	//index = expression.indexIn(text);
+    index=expression.match(text).capturedStart();
         while (index >= 0) {
-            int length = expression.matchedLength();
+            //int length = expression.matchedLength();
+            int length=expression.match(text).capturedLength();
             if (blockData->code[index]!=1) setFormat(index, length, ColorKeyword);
-            index = expression.indexIn(text, index + length);
+            //index = expression.indexIn(text, index + length);
+            index=expression.match(text,index+length).capturedStart();
         }
 
 	i=0;
 	while (i < text.length())
 		{
-		buffer = QString::null;
+		buffer = QString();
 		ch = text.at( i );
 		while ((blockData->code[i]!=1 || ch=='\\') && (!isSpace(ch)))
 		      {
