@@ -1,12 +1,13 @@
 /***************************************************************************
- *   copyright       : (C) 2003-2017 by Pascal Brachet                     *
- *   http://www.xm1math.net/texmaker/                                      *
+ *   copyright       : (C) 2003-2023 by Pascal Brachet                     *
+ *   https://www.xm1math.net/texmaker/                                     *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   @license GPL-2.0+ <https://spdx.org/licenses/GPL-2.0+.html>           *
  ***************************************************************************/
 
 #include "linenumberwidget.h"
@@ -100,8 +101,11 @@ while ( p.isValid())
 		  {
 		  if (m_editor->UserBookmark[j]==i) 
 			  {
-			  
-			  painter.fillRect(2, top,fm.width("0")+6,fm.lineSpacing(), bookmarkbrush);	  
+              #if QT_VERSION < QT_VERSION_CHECK(5, 11, 0)
+			  painter.fillRect(2, top,fm.width("0")+6,fm.lineSpacing(), bookmarkbrush);
+              #else
+              painter.fillRect(2, top,fm.horizontalAdvance("0")+6,fm.lineSpacing(), bookmarkbrush);
+              #endif
 			  painter.setPen(bookmarkpen);
 			  painter.drawText(4,top,width()-4,fm.lineSpacing(),Qt::AlignLeft | Qt::AlignTop,QString::number(j+1));
 			  }
@@ -112,8 +116,13 @@ while ( p.isValid())
 	}
 	else painter.setPen(oldpen);
 	numtext=QString::number(i);
+    #if QT_VERSION < QT_VERSION_CHECK(5, 11, 0)
 	if (p.isVisible()) painter.drawText(10+fm.width("0"), top,fm.width(numtext),fm.lineSpacing(),Qt::AlignRight | Qt::AlignTop,numtext);
-	l= fm.width(numtext)+18+fm.width("0");
+    l= fm.width(numtext)+8+fm.width("0");
+    #else
+    if (p.isVisible()) painter.drawText(10+fm.horizontalAdvance("0"), top,fm.horizontalAdvance(numtext),fm.lineSpacing(),Qt::AlignRight | Qt::AlignTop,numtext);
+    l= fm.horizontalAdvance(numtext)+8+fm.horizontalAdvance("0");
+    #endif
 	if (l>max) max=l;
 	if (i==start+1)
 	  {
@@ -130,7 +139,11 @@ while ( p.isValid())
 	  painter.drawLine(width()-15,top+(int) (fm.lineSpacing()/2)-2,width()-15,top+(int) (fm.lineSpacing()/2)+2);
 	  rangepen.setStyle(Qt::DotLine);
 	  painter.setPen(rangepen);
+      #if QT_VERSION < QT_VERSION_CHECK(5, 11, 0)
 	  painter.drawLine(fm.width("0")+8,top+fm.lineSpacing(),width()-12,top+fm.lineSpacing() );
+      #else
+      painter.drawLine(fm.horizontalAdvance("0")+8,top+fm.lineSpacing(),width()-12,top+fm.lineSpacing() );
+      #endif
 	  rangepen.setStyle(Qt::SolidLine);
 	  painter.setPen(rangepen);
 	  }
@@ -156,7 +169,11 @@ if ((rmin>=0) && (rmax>=0))
 	  painter.drawLine(width()-15,rmin+(int) (fm.lineSpacing()/2)-2,width()-15,rmin+(int) (fm.lineSpacing()/2)+2);
     	  rangepen.setStyle(Qt::DotLine);
 	  painter.setPen(rangepen);
+      #if QT_VERSION < QT_VERSION_CHECK(5, 11, 0)
       painter.drawLine(fm.width("0")+8,rmin+fm.lineSpacing(),width()-12,rmin+fm.lineSpacing() );
+      #else
+      painter.drawLine(fm.horizontalAdvance("0")+8,rmin+fm.lineSpacing(),width()-12,rmin+fm.lineSpacing() );
+      #endif
     	rangepen.setStyle(Qt::SolidLine);
 	  painter.setPen(rangepen);
       }
@@ -187,7 +204,11 @@ const QFontMetrics fm(numfont);
 QPoint p = m_editor->viewport()->mapFromGlobal(e->globalPos());
 QTextCursor cur( m_editor->cursorForPosition(p) );
 int i = m_editor->linefromblock(cur.block());
+#if QT_VERSION < QT_VERSION_CHECK(5, 11, 0)
 if (abs(p.x())<width()-fm.width("0")-6) 
+#else
+if (abs(p.x())<width()-fm.horizontalAdvance("0")-6)
+#endif
   {
   if (i==start+1) 
   {
@@ -253,7 +274,11 @@ if (event->type() == QEvent::ToolTip)
   {
   QHelpEvent *helpEvent = static_cast<QHelpEvent *>(event);
   int p = helpEvent->pos().x();
-  if (abs(p)>=fm.width("0")+8) 
+#if QT_VERSION < QT_VERSION_CHECK(5, 11, 0)
+  if (abs(p)>=fm.width("0")+8)
+#else
+   if (abs(p)>=fm.horizontalAdvance("0")+8)
+#endif
     {
      QToolTip::hideText();
      event->ignore();
