@@ -1,5 +1,5 @@
 /***************************************************************************
- *   copyright       : (C) 2003-2021 by Pascal Brachet                     *
+ *   copyright       : (C) 2003-2023 by Pascal Brachet                     *
  *   https://www.xm1math.net/texmaker/                                     *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -15,10 +15,26 @@
 #include <QPainter>
 #include <QDebug>
 
-LogEditor::LogEditor(QWidget *parent) : QPlainTextEdit(parent)
+LogEditor::LogEditor(QWidget *parent,QList<QColor> edcolors) : QPlainTextEdit(parent)
 {
+colorBackground=edcolors.at(0);
+colorLine=edcolors.at(1);
+colorHighlight=edcolors.at(2);
+colorCursor=edcolors.at(3);
+
+QPalette p = palette();
+p.setColor(QPalette::Active, QPalette::Base, colorBackground);
+p.setColor(QPalette::Inactive, QPalette::Base, colorBackground);
+p.setColor(QPalette::Inactive, QPalette::Window, colorBackground);
+p.setColor(QPalette::Active, QPalette::Window, colorBackground);
+p.setColor(QPalette::Normal,QPalette::Text,colorCursor);
+p.setColor(QPalette::Inactive, QPalette::Highlight,p.color(QPalette::Active, QPalette::Highlight));
+p.setColor(QPalette::Inactive, QPalette::HighlightedText,p.color(QPalette::Active, QPalette::HighlightedText));
+setPalette(p);
+setBackgroundVisible(true);
+
 //setToolTip(tr("Click to jump to the line"));
-highlighter = new LogHighlighter(document());
+highlighter = new LogHighlighter(document(),edcolors.at(3));
 
 connect(this, SIGNAL(cursorPositionChanged()),this, SLOT(update()));
 setReadOnly(true);
@@ -110,17 +126,37 @@ emit clickonline(l);
 
 }
 
+void LogEditor::setColors(QList<QColor> colors)
+{
+colorBackground=colors.at(0);
+colorLine=colors.at(1);
+colorHighlight=colors.at(2);
+colorCursor=colors.at(3);
+QPalette p = palette();
+p.setColor(QPalette::Active, QPalette::Base, colorBackground);
+p.setColor(QPalette::Inactive, QPalette::Base, colorBackground);
+p.setColor(QPalette::Inactive, QPalette::Window, colorBackground);
+p.setColor(QPalette::Active, QPalette::Window, colorBackground);
+p.setColor(QPalette::Normal,QPalette::Text,colorCursor);
+p.setColor(QPalette::Inactive, QPalette::Highlight,p.color(QPalette::Active, QPalette::Highlight));
+p.setColor(QPalette::Inactive, QPalette::HighlightedText,p.color(QPalette::Active, QPalette::HighlightedText));
+setPalette(p);
+setBackgroundVisible(true);
+highlighter->setColors(colors);
+update();
+}
+
 void LogEditor::paintEvent(QPaintEvent *event)
 {
-QRect rect = cursorRect();
-QRect rectbis=rect;
-rectbis.setX(0);
-rectbis.setWidth(viewport()->width());
-QPainter painter(viewport());
-const QBrush brush(QColor("#000000"));
-const QBrush brushbis(QColor("#ececec"));
-painter.fillRect(rectbis, brushbis);
-painter.fillRect(rect, brush);
-painter.end();
+// QRect rect = cursorRect();
+// QRect rectbis=rect;
+// rectbis.setX(0);
+// rectbis.setWidth(viewport()->width());
+// QPainter painter(viewport());
+// const QBrush brush(QColor("#000000"));
+// const QBrush brushbis(colorLine);
+// painter.fillRect(rectbis, brushbis);
+// painter.fillRect(rect, brush);
+// painter.end();
 QPlainTextEdit::paintEvent(event);
 }
