@@ -1,12 +1,13 @@
 /***************************************************************************
- *   copyright       : (C) 2003-2017 by Pascal Brachet                     *
- *   http://www.xm1math.net/texmaker/                                      *
+ *   copyright       : (C) 2003-2023 by Pascal Brachet                     *
+ *   https://www.xm1math.net/texmaker/                                     *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   @license GPL-2.0+ <https://spdx.org/licenses/GPL-2.0+.html>           *
  ***************************************************************************/
 
 
@@ -26,9 +27,10 @@ class LogHighlighter : public QSyntaxHighlighter
     Q_OBJECT
 
 public:
-    LogHighlighter(QTextDocument *parent = 0);
+    LogHighlighter(QTextDocument *parent = 0,QColor standard=QColor("#000000"));
     QColor ColorStandard, ColorFile, ColorError, ColorWarning;
-
+public slots:
+void setColors(QList<QColor> colors);
 protected:
     void highlightBlock(const QString &text);
 };
