@@ -1,5 +1,5 @@
 /***************************************************************************
- *   copyright       : (C) 2003-2021 by Pascal Brachet                     *
+ *   copyright       : (C) 2003-2023 by Pascal Brachet                     *
  *   https://www.xm1math.net/texmaker/                                     *
  *                                                                         *
  *   addons by Frederic Devernay <frederic.devernay@m4x.org>               *
@@ -15,6 +15,7 @@
 #include "texmakerapp.h"
 #include <QStringList>
 #include <QDebug>
+#include <QTextStream>
 #define STRINGIFY_INTERNAL(x) #x
 #define STRINGIFY(x) STRINGIFY_INTERNAL(x)
 
@@ -35,6 +36,15 @@
 
 int main( int argc, char ** argv )
 {
+
+#if !defined(Q_OS_MAC)
+QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
+#endif
+#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
+qputenv("QT_ENABLE_HIGHDPI_SCALING", "1");
+QGuiApplication::setHighDpiScaleFactorRoundingPolicy(Qt::HighDpiScaleFactorRoundingPolicy::PassThrough);
+#endif
+
 QStringList rawargs;
 for ( int i = 0; i < argc; ++i )
 	{
@@ -43,12 +53,29 @@ for ( int i = 0; i < argc; ++i )
 for (QStringList::Iterator it = ++(rawargs.begin()); it != rawargs.end(); it++)
     {
     if ( ( *it == "-dpiscale") && (++it != rawargs.end())) {qputenv("QT_SCALE_FACTOR", (*it).toUtf8());}
+    else if (  *it == "--version" )
+        {
+        QTextStream output (stdout);
+        output << QLatin1String(VERSION_STR)+QString::fromUtf8(" (compiled with Qt ")+QLatin1String(QT_VERSION_STR)+")\n";
+        output.flush();
+        return 0;
+        }
+    else if (  *it == "--help" )
+        {
+        QTextStream output (stdout);
+        output << "Usage: " <<  QString::fromUtf8("texmaker [-master] [-line xx] [-insert foo] [-n] [-dpiscale x] [file]\n\n");
+        output << QString::fromUtf8("-master : with this option, the document will be automatically defined as a master document.\n\n");
+        output << QString::fromUtf8("-line xx : with this option, Texmaker will ask you if you want to jump to the xx line after loading the document.\n\n");
+        output << QString::fromUtf8("-insert foo : with this option, a latex command foo can be inserted by an external program to the current document while texmaker is running.\n\n");
+        output << QString::fromUtf8("-n : with this option, a new instance of Texmaker is launched\n\n");
+        output << QString::fromUtf8("-dpiscale x : with this option, the environment variable QT_SCALE_FACTOR will be set to x before building the GUI\n\n");
+        output.flush();
+        return 0;
+        }
     }
 
-#if !defined(Q_OS_MAC)
-QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
-#endif
-// QStringList g_qtFlags = {"--disable-gpu"};
+
+// QStringList g_qtFlags = {"--disable-web-security"};
 // char **newArgv = appendCommandLineArguments(argc, argv, g_qtFlags);
 // int newArgc = argc + g_qtFlags.size();
 //
