@@ -1,5 +1,5 @@
 /***************************************************************************
- *   copyright       : (C) 2003-2021 by Pascal Brachet                     *
+ *   copyright       : (C) 2003-2023 by Pascal Brachet                     *
  *   https://www.xm1math.net/texmaker/                                     *
  *                                                                         *
  *   based on qpdfview  Copyright 2012 Adam Reichold GPL                   *
@@ -198,8 +198,11 @@ void PageItem::paint(QPainter* painter, const QStyleOptionGraphicsItem*, QWidget
     }
 
     // page
-
+#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
+if (qApp->devicePixelRatio()>1) image.setDevicePixelRatio(qApp->devicePixelRatio());
+#else
 if (qApp->devicePixelRatio()>=2) image.setDevicePixelRatio(qApp->devicePixelRatio());
+#endif
 
     if(s_decoratePages)
     {
@@ -642,7 +645,12 @@ void PageItem::prepareGeometry()
     }
 qreal extra=1.0;
 
+#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
+if (qApp->devicePixelRatio()>1) extra=qApp->devicePixelRatio();
+#else
 if (qApp->devicePixelRatio()>=2) extra=qApp->devicePixelRatio();
+#endif
+
 
     switch(m_rotation)
     {
