@@ -1,15 +1,17 @@
 /***************************************************************************
- *   copyright       : (C) 2003-2017 by Pascal Brachet                     *
- *   http://www.xm1math.net/texmaker/                                      *
+ *   copyright       : (C) 2003-2023 by Pascal Brachet                     *
+ *   https://www.xm1math.net/texmaker/                                     *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   @license GPL-2.0+ <https://spdx.org/licenses/GPL-2.0+.html>           *
  ***************************************************************************/
 
 #include "pdfviewer.h"
+#include "cmdparser.h"
 
 #include <QtGui>
 #include <QAction>
@@ -20,7 +22,6 @@
 #include <QSettings>
 #include <QTextStream>
 #include <QDesktopServices>
-#include <QTextCodec>
 #include <QProgressDialog>
 #include <QHeaderView>
 #include <QScrollBar>
@@ -28,7 +29,11 @@
 #include <QApplication>
 #include <QMenuBar>
 #include <QToolBar>
-#include <QDesktopWidget>
+#include <QScreen>
+#include <QWindow>
+#include <QGuiApplication>
+#include <QRegularExpression>
+
 
 #include "geticon.h"
 #include "theme.h"
@@ -54,13 +59,25 @@ QSettings *config=new QSettings(QCoreApplication::applicationDirPath()+"/texmake
 QSettings *config=new QSettings(QSettings::IniFormat,QSettings::UserScope,"xm1","texmakerpdfview");
 #endif
 config->beginGroup( "pdfviewer" );
-QRect screen = QApplication::desktop()->screenGeometry();
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 14, 0))
+   QRect screen = QWidget::screen()->geometry();
+ #else
+  QRect screen = (window() && window()->windowHandle() ? window()->windowHandle()->screen()->geometry() : QGuiApplication::primaryScreen()->geometry());
+#endif
 int w= config->value( "Geometries/MainwindowWidth",screen.width()/2).toInt();
 int h= config->value( "Geometries/MainwindowHeight",screen.height()-150).toInt() ;
 int x= config->value( "Geometries/MainwindowX",screen.width()/2).toInt();
 int y= config->value( "Geometries/MainwindowY",30).toInt() ;
-resize(w,h);
-move(x,y);
+if ((x+w<=screen.width()) && (y+h<=screen.height()))
+    {
+    resize(w,h);
+    move(x,y);
+    }
+else
+    {
+    resize(screen.width()/2,screen.height()-150);
+    move(screen.width()/2,30);
+    }
 windowstate=config->value("MainWindowState").toByteArray();
 showingListPages=config->value( "Gui/ListPages",true).toBool();
 config->endGroup();
@@ -140,7 +157,7 @@ LeftPanelStackedWidget->addWidget(StructureTreeView);
 
 
 LeftPanelLayout->setSpacing(0);
-LeftPanelLayout->setMargin(0);
+LeftPanelLayout->setContentsMargins(0,0,0,0);
 LeftPanelLayout->addWidget(LeftPanelToolBar);
 LeftPanelLayout->addWidget(LeftPanelStackedWidget);
 StructureView->setWidget(LeftPanelFrame);
@@ -158,7 +175,7 @@ pdfview=new DocumentView(centralFrame);
 
 CentralLayout= new QHBoxLayout(centralFrame);
 CentralLayout->setSpacing(0);
-CentralLayout->setMargin(0);
+CentralLayout->setContentsMargins(0,0,0,0);
 CentralLayout->addWidget(pdfview);
 
 setCentralWidget(centralFrame);
@@ -168,11 +185,11 @@ QMenu *fileMenu = menuBar()->addMenu(tr("&File"));
 //printAct = new QAction(getIcon(":/images/print.png"), tr("Print"), this);
 //connect(printAct, SIGNAL(triggered()), this, SLOT(printPdf()));
 //fileMenu->addAction(printAct);
-fileMenu->addAction(tr("Exit"), this, SLOT(close()),Qt::CTRL+Qt::Key_Q);
+fileMenu->addAction(tr("Exit"), this, SLOT(close()),Qt::CTRL | Qt::Key_Q);
 
 QMenu *editMenu = menuBar()->addMenu(tr("&Edit"));
 findAct = new QAction( tr("Find"), this);
-findAct->setShortcut(Qt::CTRL+Qt::Key_F);
+findAct->setShortcut(Qt::CTRL | Qt::Key_F);
 editMenu->addAction(findAct);
 
 
@@ -219,11 +236,11 @@ twoPagesModeAction->setChecked(false);
 viewMenu->addAction(twoPagesModeAction);
   
 rotateLeftAction = new QAction(tr("Rotate left"), this);
-rotateLeftAction->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_Left));
+rotateLeftAction->setShortcut(QKeySequence(Qt::CTRL  | Qt::Key_Left));
 viewMenu->addAction(rotateLeftAction);
   
 rotateRightAction = new QAction(tr("Rotate right"), this);
-rotateRightAction->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_Right));
+rotateRightAction->setShortcut(QKeySequence(Qt::CTRL  | Qt::Key_Right));
 viewMenu->addAction(rotateRightAction);
 
 presentationAction = new QAction(tr("Presentation..."), this);
@@ -231,6 +248,8 @@ viewMenu->addAction(presentationAction);
   
 viewMenu->addSeparator();
 viewMenu->addAction(StructureView->toggleViewAction());
+//connect(StructureView->toggleViewAction(),SIGNAL(toggled(bool)), this, SLOT(ToggleStructureView()));
+
 
 
 historyBackAct = new QAction(getIcon(":/images/errorprev.png"), tr("Previous Position"), this);
@@ -248,15 +267,20 @@ connect( this, SIGNAL( forwardAvailable( bool ) ), historyForwardAct, SLOT( setE
 
 scaleComboBox = new QComboBox(toolBar);
 zoomCustom = new QLineEdit();
-//QValidator *validatorZoom = new QIntValidator(25, 400, this);
-QValidator *validatorZoom = new QRegExpValidator(QRegExp("\\d{0,3}%?"), this);
+QValidator *validatorZoom = new QRegularExpressionValidator(QRegularExpression("\\d{0,3}%?"), this);
 zoomCustom->setValidator(validatorZoom);
 scaleComboBox->setInsertPolicy(QComboBox::NoInsert);
-scalePercents << "25%" << "50%" << "75%" << "100%" << "125%" << "150%" << "200%" << "300%" << "400%";
+scalePercents << "25%" << "50%" << "75%" << "100%" << "125%" << "150%" << "200%" << "300%" << "400%" << "500%" << "600%" << "700%" << "800%";
 scaleComboBox->addItems(scalePercents);
 scaleComboBox->setCurrentIndex(3);
 scaleComboBox->setEditable(true);
 scaleComboBox->setLineEdit(zoomCustom);
+QFontMetrics fm(qApp->font());
+#if QT_VERSION < QT_VERSION_CHECK(5, 11, 0)
+scaleComboBox->setMinimumWidth(fm.width("WWWWW"));
+#else
+scaleComboBox->setMinimumWidth(fm.horizontalAdvance("WWWWW"));
+#endif
 scaleComboBox->setStyleSheet(Theme::comboboxStyleSheet);
 toolBar->addWidget(scaleComboBox);
 
@@ -303,9 +327,12 @@ presentationAction->setEnabled(false);
 
 restoreState(windowstate);
 
+
 //restoreDockWidget(StructureView);
 if (showingListPages) ShowListPages();
 openFile(pdf_file,viewpdf_command,gswin32c_command);
+previous_structureview_status=StructureView->toggleViewAction()->isChecked();
+
 }
 
 PdfViewer::~PdfViewer()
@@ -380,16 +407,21 @@ if (pdfview->open(fn))
   pdfview->setContinousMode(islastContinuous);
     twoPagesModeAction->setEnabled(true);
   //pdfview->setTwoPagesMode(false);
-  pdfview->show();
+  //pdfview->show();
   
   StructureTreeView->setModel(pdfview->outlineModel());
   QString syncFile = QFileInfo(fn).canonicalFilePath();
   scanner = synctex_scanner_new_with_output_file(syncFile.toUtf8().data(), NULL, 1);
+
+  connectActions();
+   pdfview->show();
+
   if ((fn==lastFile) && (lpage <= pdfview->doc()->pageCount()) && (lpage>0))
     {
     currentPage=lpage;
     currentScale=lscale;
-    if ((currentScale < 0.25) || (currentScale > 4)) 
+
+    if ((currentScale < 0.25) || (currentScale > 8))
       {
       pdfview->setScaleMode(DocumentView::FitToPageWidth);
       currentScale=pdfview->realScale();
@@ -399,6 +431,7 @@ if (pdfview->open(fn))
     else 
       {
       zoomCustom->setText(QString::number(int(currentScale*100)) + "%");
+      pdfview->setScaleMode(DocumentView::ScaleFactor);
       pdfview->setScaleFactor(currentScale);
       }
     }
@@ -422,7 +455,7 @@ if (pdfview->open(fn))
   else ShowStructure();
   lastScale=currentScale;
   previousScale=currentScale;
-  connectActions();
+  //connectActions();
   gotoPage(currentPage);
   disconnect(pdfview,SIGNAL(doHScroll(int)), this, SLOT(setHpos(int)));
   if (pdfview->horizontalScrollBar()->isVisible())  {QTimer::singleShot( 500,this, SLOT(jumptoHpos()) );}
@@ -453,6 +486,8 @@ else
   listpagesWidget->clear();
   pdfview->clearAll();
   }
+current_width=pdfview->viewport()->width();
+
 }
 
 
@@ -469,7 +504,7 @@ connect(fitPageAct, SIGNAL(triggered()), this, SLOT(fitPage()));
 connect(zoominAct, SIGNAL(triggered()), this, SLOT(zoomIn()));
 connect(zoomoutAct, SIGNAL(triggered()), this, SLOT(zoomOut()));
 connect(zoomCustom, SIGNAL(returnPressed()),this, SLOT(userZoom()));
-connect(scaleComboBox, SIGNAL(currentIndexChanged(QString)),this, SLOT(scaleDocumentZoom(QString)));
+connect(scaleComboBox, SIGNAL(currentTextChanged(QString)),this, SLOT(scaleDocumentZoom(QString)));
 connect(searchLineEdit, SIGNAL(returnPressed()), this, SLOT(searchDocument()));
 connect(searchAct, SIGNAL(triggered()), this, SLOT(searchDocument()));
 //connect(findButton, SIGNAL(clicked()), this, SLOT(searchDocument()));
@@ -485,6 +520,8 @@ connect(pdfview, SIGNAL(requestZoomOut()), this, SLOT(zoomOut()));
 connect(pdfview, SIGNAL(continousModeChanged(bool)), this,SLOT(on_currentTab_continuousModeChanged(bool)));
 connect(pdfview, SIGNAL(twoPagesModeChanged(bool)), this,SLOT(on_currentTab_twoPagesModeChanged(bool)));
 connect(pdfview,SIGNAL(doHScroll(int)), this, SLOT(setHpos(int)));
+connect(pdfview, SIGNAL(sizehaschanged()), this, SLOT(LayoutHasChanged()));
+connect(pdfview, SIGNAL(scaleFactorChanged(qreal)), this, SLOT(scaleModified()));
 connect(continuousModeAction, SIGNAL(triggered(bool)),this, SLOT(on_continuousMode_triggered(bool)));
 connect(twoPagesModeAction, SIGNAL(triggered(bool)),this, SLOT(on_twoPagesMode_triggered(bool)));
 connect(rotateLeftAction, SIGNAL(triggered()), this,SLOT(on_rotateLeft_triggered()));
@@ -508,7 +545,7 @@ disconnect(fitPageAct, SIGNAL(triggered()), this, SLOT(fitPage()));
 disconnect(zoominAct, SIGNAL(triggered()), this, SLOT(zoomIn()));
 disconnect(zoomoutAct, SIGNAL(triggered()), this, SLOT(zoomOut()));
 disconnect(zoomCustom, SIGNAL(returnPressed()),this, SLOT(userZoom()));
-disconnect(scaleComboBox, SIGNAL(currentIndexChanged(QString)),this, SLOT(scaleDocumentZoom(QString)));
+disconnect(scaleComboBox, SIGNAL(currentTextChanged(QString)),this, SLOT(scaleDocumentZoom(QString)));
 disconnect(searchLineEdit, SIGNAL(returnPressed()), this, SLOT(searchDocument()));
 disconnect(searchAct, SIGNAL(triggered()), this, SLOT(searchDocument()));
 //disconnect(findButton, SIGNAL(clicked()), this, SLOT(searchDocument()));
@@ -524,6 +561,8 @@ disconnect(pdfview, SIGNAL(requestZoomOut()), this, SLOT(zoomOut()));
 disconnect(pdfview, SIGNAL(continousModeChanged(bool)), this,SLOT(on_currentTab_continuousModeChanged(bool)));
 disconnect(pdfview, SIGNAL(twoPagesModeChanged(bool)), this,SLOT(on_currentTab_twoPagesModeChanged(bool)));
 disconnect(pdfview,SIGNAL(doHScroll(int)), this, SLOT(setHpos(int)));
+disconnect(pdfview, SIGNAL(sizehaschanged()), this, SLOT(LayoutHasChanged()));
+disconnect(pdfview, SIGNAL(scaleFactorChanged(qreal)), this, SLOT(scaleModified()));
 disconnect(continuousModeAction, SIGNAL(triggered(bool)), this,SLOT(on_continuousMode_triggered(bool)));
 disconnect(twoPagesModeAction, SIGNAL(triggered(bool)), this,SLOT(on_twoPagesMode_triggered(bool)));
 disconnect(rotateLeftAction, SIGNAL(triggered()), this,SLOT(on_rotateLeft_triggered()));
@@ -547,7 +586,7 @@ if (scanner == NULL)
   }
 const QFileInfo sourceFileInfo(sourceFile);
 QDir curDir(QFileInfo(pdf_file).canonicalPath());
-synctex_node_t node = synctex_scanner_input(scanner);
+synctex_node_p node = synctex_scanner_input(scanner);
 QString name;
 bool found = false;
 while (node != NULL) 
@@ -566,11 +605,11 @@ if (!found)
   gotoPage(currentPage);
   return;
   }
-if (synctex_display_query(scanner, name.toUtf8().data(), source_line, 0) > 0) 
+if (synctex_display_query(scanner, name.toUtf8().data(), source_line,source_col, 0) > 0)
   {
   int page = -1;
   path= QPainterPath();
-  while ((node = synctex_next_result(scanner)) != NULL) 
+  while ((node = synctex_scanner_next_result(scanner)) != NULL)
     {
     if (page == -1) page = synctex_node_page(node);
     if (synctex_node_page(node) != page) continue;
@@ -663,21 +702,23 @@ void PdfViewer::scaleDocumentZoom(QString zoom)
 {
 if (!fileLoaded) return;
 if (zoom.contains("%")) zoom.remove("%");
-if (zoom.toInt() > 0 && zoom.toInt() <= 400)
+if (zoom.toInt() > 0 && zoom.toInt() <= 800)
   {
     qreal s=1;
   currentScale=zoom.toFloat() / 100.0;
   if (currentScale < 0.25) currentScale = 0.25;
-  else if (currentScale > 4) currentScale = 4;
+  else if (currentScale > 8) currentScale = 8;
   if (previousScale!=0)  s=currentScale/previousScale;
 //   int newhpos=(int) (s*(pdfview->horizontalScrollBar()->value()+pdfview->viewport()->width()/2)-pdfview->viewport()->width()/2);
 //   int newvpos=(int) (s*(pdfview->verticalScrollBar()->value()+pdfview->viewport()->height()/2)-pdfview->viewport()->height()/2);
 
   pdfview->setScaleMode(DocumentView::ScaleFactor);
-  pdfview->setScaleFactor(s*pdfview->scaleFactor());
+  pdfview->setScaleFactor(currentScale);
+//  pdfview->setScaleFactor(s*pdfview->scaleFactor());
   currentScale=pdfview->realScale();
   lastScale=currentScale;
   previousScale=currentScale;
+
 //   pdfview->horizontalScrollBar()->setValue(newhpos);
 //   pdfview->verticalScrollBar()->setValue(newvpos);
    clearHistory();
@@ -861,9 +902,9 @@ if (currentScale < 0.25)
   zoomCustom->setText(QString::number(int(currentScale*100)) + "%");
   scaleDocumentZoom(zoomCustom->text());
   }
-else if (currentScale > 4) 
+else if (currentScale > 8)
   {
-  currentScale = 4;
+  currentScale = 8;
   zoomCustom->setText(QString::number(int(currentScale*100)) + "%");
   scaleDocumentZoom(zoomCustom->text());
   }
@@ -885,9 +926,9 @@ if (currentScale < 0.25)
   zoomCustom->setText(QString::number(int(currentScale*100)) + "%");
   scaleDocumentZoom(zoomCustom->text());
   }
-else if (currentScale > 4) 
+else if (currentScale > 8)
   {
-  currentScale = 4;
+  currentScale = 8;
   zoomCustom->setText(QString::number(int(currentScale*100)) + "%");
   scaleDocumentZoom(zoomCustom->text());
   }
@@ -901,7 +942,7 @@ void PdfViewer::zoomIn()
 if (!fileLoaded) return;
 previousScale=currentScale;
 currentScale+=0.1;
-if (currentScale > 4) currentScale = 4;
+if (currentScale > 8) currentScale = 8;
 lastScale=currentScale;
 zoomCustom->setText(QString::number(int(currentScale*100)) + "%");
 scaleDocumentZoom(zoomCustom->text());
@@ -928,7 +969,9 @@ if (fi.exists())
 	{
 	proc = new QProcess( this );
 	proc->setWorkingDirectory(fi.absolutePath());
-	proc->start(command);
+    const cmdInfo commandInfo=splitCommand(command);
+    proc->start(commandInfo.program,commandInfo.arguments);
+	//proc->start(command);
 	}
 }
 
@@ -996,9 +1039,9 @@ pdfview->print(&printer);
       default:
 	      break;
       }
-  switch(printer.orientation()) 
+  switch(printer.pageLayout().orientation())
       {
-      case QPrinter::Landscape:
+      case QPageLayout::Landscape:
 	      args << "-o landscape";
 	      break;
       default:
@@ -1026,8 +1069,8 @@ void PdfViewer::jumpToEditor(int page, const QPointF& pos)
 if (scanner == NULL) return;
 if (synctex_edit_query(scanner, page+1, pos.x(), pos.y()) > 0) 
   {
-  synctex_node_t node;
-  while ((node = synctex_next_result(scanner)) != NULL) 
+  synctex_node_p node;
+  while ((node = synctex_scanner_next_result(scanner)) != NULL)
     {
     QString filename = QString::fromUtf8(synctex_scanner_get_name(scanner, synctex_node_tag(node)));
     QDir curDir(QFileInfo(pdf_file).canonicalPath());
@@ -1218,3 +1261,27 @@ void PdfViewer::on_currentTab_twoPagesModeChanged(bool twoPagesMode)
 {
 twoPagesModeAction->setChecked(twoPagesMode);
 }
+
+void PdfViewer::LayoutHasChanged()
+{
+if (previous_structureview_status!=StructureView->toggleViewAction()->isChecked())
+    {
+
+    if (!fileLoaded) return;
+    previousScale=currentScale;
+    if (current_width!=0) currentScale=currentScale*pdfview->viewport()->width()/current_width;
+    if (currentScale > 8) currentScale = 8;
+    lastScale=currentScale;
+    zoomCustom->setText(QString::number(int(currentScale*100)) + "%");
+
+    scaleDocumentZoom(zoomCustom->text());
+    //scaleDocumentZoom(QString::number(currentScale));
+    current_width=current_width=pdfview->viewport()->width();
+    previous_structureview_status=StructureView->toggleViewAction()->isChecked();
+    }
+}
+void PdfViewer::scaleModified()
+{
+    emit scaleHasChanged();
+
+}
