@@ -1,12 +1,13 @@
 /***************************************************************************
- *   copyright       : (C) 2003-2017 by Pascal Brachet                     *
- *   http://www.xm1math.net/texmaker/                                      *
+ *   copyright       : (C) 2003-2023 by Pascal Brachet                     *
+ *   https://www.xm1math.net/texmaker/                                     *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   @license GPL-2.0+ <https://spdx.org/licenses/GPL-2.0+.html>           *
  ***************************************************************************/
 
 #ifndef PDFVIEWER_H
@@ -68,6 +69,7 @@ QByteArray windowstate;
 
 DocumentView* pdfview;
 
+
 QAction *upAct, *downAct, *fitWithAct, *fitPageAct, *zoominAct, *zoomoutAct, *findAct, *historyBackAct, *historyForwardAct,*printAct, *externAct, *searchAct;
 
 QAction *continuousModeAction, *twoPagesModeAction, *rotateLeftAction, *rotateRightAction, *presentationAction;
@@ -85,7 +87,7 @@ bool fileLoaded;
 QPointer<QProcess> proc;
 QString lastFile;
 int lastPage, altern;
-synctex_scanner_t scanner;
+synctex_scanner_p scanner;
 QStringList scalePercents;
 QLineEdit *zoomCustom;
 int lastSearchPos;
@@ -96,6 +98,10 @@ bool showingListPages;
 int lastHpos;
 bool islastContinuous;
 
+int current_width;
+bool previous_structureview_status;
+
+
 
 private slots:
 void connectActions();
@@ -141,6 +147,9 @@ void on_presentation_triggered();
 
 void on_currentTab_continuousModeChanged(bool continuousMode);
 void on_currentTab_twoPagesModeChanged(bool twoPagesMode);
+
+void LayoutHasChanged();
+void scaleModified();
     
 
 protected:
@@ -152,6 +161,7 @@ void sendFocusToEditor();
 void sendPaperSize(const QString&);
 void backwardAvailable(bool);
 void forwardAvailable(bool);
+void scaleHasChanged();
 };
 
 #endif
