@@ -1,5 +1,5 @@
 /***************************************************************************
- *   copyright       : (C) 2003-2021 by Pascal Brachet                     *
+ *   copyright       : (C) 2003-2023 by Pascal Brachet                     *
  *   https://www.xm1math.net/texmaker/                                     *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -170,16 +170,21 @@ scaleComboBox = new QComboBox(centralToolBarBis);
 
 zoomCustom = new QLineEdit();
 
-//QValidator *validatorZoom = new QIntValidator(25, 400, this);
+
 QValidator *validatorZoom = new QRegularExpressionValidator(QRegularExpression("\\d{0,3}%?"), this);
 zoomCustom->setValidator(validatorZoom);
 scaleComboBox->setInsertPolicy(QComboBox::NoInsert);
-scalePercents << "25%" << "50%" << "75%" << "100%" << "125%" << "150%" << "200%" << "300%" << "400%";
+scalePercents << "25%" << "50%" << "75%" << "100%" << "125%" << "150%" << "200%" << "300%" << "400%" << "500%" << "600%" << "700%" << "800%";
 scaleComboBox->addItems(scalePercents);
 scaleComboBox->setCurrentIndex(3);
 scaleComboBox->setEditable(true);
 scaleComboBox->setLineEdit(zoomCustom);
-
+QFontMetrics fm(qApp->font());
+#if QT_VERSION < QT_VERSION_CHECK(5, 11, 0)
+scaleComboBox->setMinimumWidth(fm.width("WWWWW"));
+#else
+scaleComboBox->setMinimumWidth(fm.horizontalAdvance("WWWWW"));
+#endif
 scaleComboBox->setStyleSheet(Theme::comboboxStyleSheet);
 centralToolBarBis->addWidget(scaleComboBox);
 
@@ -336,7 +341,7 @@ if (pdfview->open(fn))
   continuousModeAction->setChecked(islastContinuous);//
   //pdfview->setTwoPagesMode(false);
   //twoPagesModeAction->setChecked(false);
-  pdfview->show();
+//  pdfview->show();
   searchLineEdit->setEnabled(true);
   searchAct->setEnabled(true);
   //findButton->setEnabled(true);
@@ -352,11 +357,14 @@ if (pdfview->open(fn))
    QString syncFile = QFileInfo(fn).canonicalFilePath();
    scanner = synctex_scanner_new_with_output_file(syncFile.toUtf8().data(), NULL, 1);
 
+   connectActions();
+   pdfview->show();
+
   if ((fn==lastFile) && (lpage <= pdfview->doc()->pageCount()) && (lpage>0))
     {
     currentPage=lpage;
     currentScale=lscale;
-    if ((currentScale < 0.25) || (currentScale > 4)) 
+    if ((currentScale < 0.25) || (currentScale > 8))
       {
       pdfview->setScaleMode(DocumentView::FitToPageWidth);
       currentScale=pdfview->realScale();
@@ -394,7 +402,7 @@ if (pdfview->open(fn))
   clearHistory();
   lastScale=currentScale;
   previousScale=currentScale;
-  connectActions();
+//  connectActions();
   gotoPage(currentPage);
   disconnect(pdfview,SIGNAL(doHScroll(int)), this, SLOT(setHpos(int)));
   if (pdfview->horizontalScrollBar()->isVisible())  {QTimer::singleShot( 500,this, SLOT(jumptoHpos()) );}
@@ -632,12 +640,12 @@ void PdfViewerWidget::scaleDocumentZoom(QString zoom)
 {
 if (!fileLoaded) return;
 if (zoom.contains("%")) zoom.remove("%");
-if (zoom.toInt() > 0 && zoom.toInt() <= 400)
+if (zoom.toInt() > 0 && zoom.toInt() <= 800)
   {
     qreal s=1;
   currentScale=zoom.toFloat() / 100.0;
   if (currentScale < 0.25) currentScale = 0.25;
-  else if (currentScale > 4) currentScale = 4;
+  else if (currentScale > 8) currentScale = 8;
   if (previousScale!=0)  s=currentScale/previousScale;
 //   int newhpos=(int) (s*(pdfview->horizontalScrollBar()->value()+pdfview->viewport()->width()/2)-pdfview->viewport()->width()/2);
 //   int newvpos=(int) (s*(pdfview->verticalScrollBar()->value()+pdfview->viewport()->height()/2)-pdfview->viewport()->height()/2);
@@ -831,9 +839,9 @@ if (currentScale < 0.25)
   zoomCustom->setText(QString::number(int(currentScale*100)) + "%");
   scaleDocumentZoom(zoomCustom->text());
   }
-else if (currentScale > 4) 
+else if (currentScale > 8)
   {
-  currentScale = 4;
+  currentScale = 8;
   zoomCustom->setText(QString::number(int(currentScale*100)) + "%");
   scaleDocumentZoom(zoomCustom->text());
   }
@@ -855,9 +863,9 @@ if (currentScale < 0.25)
   zoomCustom->setText(QString::number(int(currentScale*100)) + "%");
   scaleDocumentZoom(zoomCustom->text());
   }
-else if (currentScale > 4) 
+else if (currentScale > 8)
   {
-  currentScale = 4;
+  currentScale = 8;
   zoomCustom->setText(QString::number(int(currentScale*100)) + "%");
   scaleDocumentZoom(zoomCustom->text());
   }
@@ -871,7 +879,7 @@ void PdfViewerWidget::zoomIn()
 if (!fileLoaded) return;
 previousScale=currentScale;
 currentScale+=0.1;
-if (currentScale > 4) currentScale = 4;
+if (currentScale > 8) currentScale = 8;
 lastScale=currentScale;
 zoomCustom->setText(QString::number(int(currentScale*100)) + "%");
 scaleDocumentZoom(zoomCustom->text());
