@@ -1,5 +1,5 @@
 /***************************************************************************
- *   copyright       : (C) 2003-2021 by Pascal Brachet                     *
+ *   copyright       : (C) 2003-2023 by Pascal Brachet                     *
  *   https://www.xm1math.net/texmaker/                                     *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -25,7 +25,11 @@ state = true;
 void PlayerButton::setImages( QString name )
 {
 
+#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
+if (qApp->devicePixelRatio()>1)
+#else
 if (qApp->devicePixelRatio()>=2)
+#endif
   {
   this->pixEnabled.load(":/images/"+name+"_enabled@2x.png");
   this->pixEnabled.setDevicePixelRatio(qApp->devicePixelRatio());
