@@ -1,35 +1,26 @@
+/***************************************************************************
+ *   copyright       : (C) 2003-2023 by Pascal Brachet                     *
+ *   https://www.xm1math.net/texmaker/                                     *
+ *                                                                         *
+ *   based on qpdfview  Copyright 2012 Adam Reichold GPL                   *
+ *   This program is free software; you can redistribute it and/or modify  *
+ *   it under the terms of the GNU General Public License as published by  *
+ *   the Free Software Foundation; either version 2 of the License, or     *
+ *   (at your option) any later version.                                   *
+ *                                                                         *
+ *   @license GPL-2.0+ <https://spdx.org/licenses/GPL-2.0+.html>           *
+ ***************************************************************************/
+
 /*
 
 Copyright 2012 Adam Reichold
 
 This file is part of qpdfview.
 
-qpdfview is free software: you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation, either version 2 of the License, or
-(at your option) any later version.
-
-qpdfview is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with qpdfview.  If not, see <http://www.gnu.org/licenses/>.
+modified by Pascal Brachet
 
 */
 
-/***************************************************************************
- *   copyright       : (C) 2003-2017 by Pascal Brachet                     *
- *   http://www.xm1math.net/texmaker/                                      *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
-
 #ifndef PRESENTATIONVIEW_H
 #define PRESENTATIONVIEW_H
 
