@@ -34,14 +34,15 @@
 **
 ****************************************************************************/
 /***************************************************************************
- *   copyright       : (C) 2003-2017 by Pascal Brachet                     *
- *   http://www.xm1math.net/texmaker/                                      *
+ *   copyright       : (C) 2003-2023 by Pascal Brachet                     *
+ *   https://www.xm1math.net/texmaker/                                     *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   @license GPL-2.0+ <https://spdx.org/licenses/GPL-2.0+.html>           *
  ***************************************************************************/
 
 #include "qpdfdocument.h"
@@ -57,11 +58,21 @@
 QT_BEGIN_NAMESPACE
 
 // The library is not thread-safe at all, it has a lot of global variables.
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 Q_GLOBAL_STATIC_WITH_ARGS(QMutex, pdfMutex, (QMutex::Recursive));
+#else
+Q_GLOBAL_STATIC(QRecursiveMutex, pdfMutex)
+#endif
+
+
 static int libraryRefCount;
 
 QPdfMutexLocker::QPdfMutexLocker()
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     : QMutexLocker(pdfMutex())
+#else
+    : std::unique_lock<QRecursiveMutex>(*pdfMutex())
+#endif
 {
 }
 
