@@ -1,5 +1,5 @@
 /***************************************************************************
- *   copyright       : (C) 2003-2021 by Pascal Brachet                     *
+ *   copyright       : (C) 2003-2023 by Pascal Brachet                     *
  *   https://www.xm1math.net/texmaker/                                     *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -52,9 +52,9 @@ ui.replaceallButton->setStyleSheet(Theme::buttonSearchStyleSheet);
 ui.closeButton->setStyleSheet(Theme::buttonSearchStyleSheet);
 ui.moreButton->setStyleSheet(Theme::buttonSearchStyleSheet);
 ui.comboFind->setStyleSheet(Theme::comboboxSearchStyleSheet);
-ui.comboFind->lineEdit()->setStyleSheet(Theme::lineeditSearchStyleSheet);
+//ui.comboFind->lineEdit()->setStyleSheet(Theme::lineeditSearchStyleSheet);
 ui.comboReplace->setStyleSheet(Theme::comboboxSearchStyleSheet);
-ui.comboReplace->lineEdit()->setStyleSheet(Theme::lineeditSearchStyleSheet);
+//ui.comboReplace->lineEdit()->setStyleSheet(Theme::lineeditSearchStyleSheet);
 updateGeometry();
 }
 
@@ -94,7 +94,7 @@ if (ui.checkSelection->isChecked())
      if (result>-1)
       {
       startpos=result;
-      switch(  QMessageBox::warning(this, "Texmaker",tr("Replace this occurence ? "),tr("Yes"), tr("No"), tr("Cancel"), 0,2 ) )
+      switch(  QMessageBox::warning(this, "Texmaker",tr("Replace this occurrence ? "),tr("Yes"), tr("No"), tr("Cancel"), 0,2 ) )
 	{
 	case 0:
 	replaceSelection();  
@@ -117,7 +117,7 @@ else
   while (go && editor->search( ui.comboFind->currentText(), ui.checkCase->isChecked(),
 	  ui.checkWords->isChecked(), ui.radioForward->isChecked(), !ui.checkBegin->isChecked(),ui.checkRegExp->isChecked()) )
 	{
-	switch(  QMessageBox::warning(this, "Texmaker",tr("Replace this occurence ? "),tr("Yes"), tr("No"), tr("Cancel"), 0,2 ) )
+	switch(  QMessageBox::warning(this, "Texmaker",tr("Replace this occurrence ? "),tr("Yes"), tr("No"), tr("Cancel"), 0,2 ) )
 	  {
 	  case 0:
 	  editor->replace(ui.comboReplace->currentText(),ui.checkRegExp->isChecked(),ui.comboFind->currentText() );
