@@ -1,12 +1,13 @@
 /***************************************************************************
- *   copyright       : (C) 2003-2017 by Pascal Brachet                     *
- *   http://www.xm1math.net/texmaker/                                      *
+ *   copyright       : (C) 2003-2023 by Pascal Brachet                     *
+ *   https://www.xm1math.net/texmaker/                                     *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   @license GPL-2.0+ <https://spdx.org/licenses/GPL-2.0+.html>           *
  ***************************************************************************/
 
 #include "sourceview.h"
@@ -36,7 +37,7 @@ framebis->setFrameStyle(QFrame::NoFrame);
 
 QVBoxLayout* mainlay = new QVBoxLayout(framebis );
 mainlay->setSpacing(0);
-mainlay->setMargin(0);
+mainlay->setContentsMargins(0,0,0,0);
 
 centralToolBar=new QToolBar("ToolBar",framebis);
 centralToolBar->setFloatable(false);
@@ -76,10 +77,14 @@ connect(editor, SIGNAL(requestGotoLine()), this, SLOT(showGoto()));
 m_lineNumberWidget = new LightLineNumberWidget( editor, frame);
 m_lineNumberWidget->setFont(efont);
 QFontMetrics fm( efont );
+#if QT_VERSION < QT_VERSION_CHECK(5, 11, 0)
 m_lineNumberWidget->setFixedWidth( fm.width( "00000" ) + 22 );
+#else
+m_lineNumberWidget->setFixedWidth( fm.horizontalAdvance( "00000" ) + 22 );
+#endif
 QHBoxLayout* lay = new QHBoxLayout( frame );
 lay->setSpacing(0);
-lay->setMargin(0);
+lay->setContentsMargins(0,0,0,0);
 lay->addWidget( m_lineNumberWidget );
 lay->addWidget( editor );
 setFocusProxy( editor );
@@ -108,8 +113,21 @@ splitter->addWidget(Stack);
 
 QVBoxLayout *mainlayout= new QVBoxLayout(this);
 mainlayout->setSpacing(0);
-mainlayout->setMargin(0);
+mainlayout->setContentsMargins(0,0,0,0);
 mainlayout->addWidget(splitter);
+setAutoFillBackground( true );
+QPalette pal( palette() );
+pal.setColor( QPalette::Active, QPalette::WindowText,Theme::grayColor );
+pal.setColor( QPalette::Inactive, QPalette::WindowText, Theme::grayColor );
+pal.setColor( QPalette::Disabled, QPalette::WindowText, Theme::grayColor );
+pal.setColor( QPalette::Active, QPalette::HighlightedText, Theme::grayColor );
+pal.setColor( QPalette::Inactive, QPalette::HighlightedText, Theme::grayColor );
+pal.setColor( QPalette::Disabled, QPalette::HighlightedText,Theme::grayColor );
+pal.setColor( QPalette::Active, QPalette::Base, Theme::grayColor );
+pal.setColor( QPalette::Inactive, QPalette::Base, Theme::grayColor );
+pal.setColor( QPalette::Disabled, QPalette::Base, Theme::grayColor);
+pal.setColor(QPalette::Window, Theme::darkbackgroundColor);
+setPalette( pal );
 }
 
 SourceView::~SourceView()
@@ -130,7 +148,11 @@ void SourceView::changeSettings(QFont & new_font,bool line)
   editor->changeFont(new_font);
   m_lineNumberWidget->setFont(new_font);
   QFontMetrics fm( new_font );
+  #if QT_VERSION < QT_VERSION_CHECK(5, 11, 0)
   m_lineNumberWidget->setFixedWidth( fm.width( "00000" ) + 32 );
+  #else
+  m_lineNumberWidget->setFixedWidth( fm.horizontalAdvance( "00000" ) + 32 );
+  #endif
   setLineNumberWidgetVisible(line);
 }
 
