@@ -1,11 +1,13 @@
 /***************************************************************************
- *   copyright       : (C) 2007-2017 by Pascal Brachet                     *
+ *   copyright       : (C) 2003-2023 by Pascal Brachet                     *
+ *   https://www.xm1math.net/texmaker/                                     *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   @license GPL-2.0+ <https://spdx.org/licenses/GPL-2.0+.html>           *
  ***************************************************************************/
 
 #include "spellerdialog.h"
@@ -16,11 +18,15 @@
 #include <QMessageBox>
 #include <QTimer>
 #include <QCloseEvent>
-#include <QTextCodec>
 #include <QTextStream>
 #include <QTextCharFormat>
 #include <QFileInfo>
 #include <QApplication>
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+    #include <QtCore/QTextCodec>
+#else
+    #include <QtCore5Compat/QTextCodec>
+#endif
 #include "blockdata.h"
 
 SpellerDialog::SpellerDialog(QWidget *parent,LatexEditor *ed,QString ignoredWords)
@@ -316,7 +322,7 @@ text=block.text();
 blockData= (BlockData*)block.userData();
 while (gonext && i < text.length())
 	{
-	buffer = QString::null;
+	buffer = QString();
 	ch = text.at( i );
 	offset=0;
 	while ((blockData->code[i]!=1) && (!isSpace(ch)))
