@@ -1,16 +1,20 @@
 /***************************************************************************
- *   copyright       : (C) 2003-2017 by Pascal Brachet                     *
- *   http://www.xm1math.net/texmaker/                                      *
+ *   copyright       : (C) 2003-2023 by Pascal Brachet                     *
+ *   https://www.xm1math.net/texmaker/                                     *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   @license GPL-2.0+ <https://spdx.org/licenses/GPL-2.0+.html>           *
  ***************************************************************************/
 
 #include "svnhelper.h"
+#include "cmdparser.h"
+
 #include <QProcess>
+#include <QRegularExpression>
 #include <QDebug>
 
 
@@ -81,17 +85,18 @@ void SvnHelper::parseUnified(int exitCode, QProcess::ExitStatus exitStatus)
             break;
         }
         QString position = _process.readLine();
-        QRegExp positionRegex("^\\@ \\-(\\d+),(\\d+) \\+(\\d+),(\\d+) \\@\\@");
-        if(!position.contains(positionRegex))
+        QRegularExpression positionRegex("^\\@ \\-(\\d+),(\\d+) \\+(\\d+),(\\d+) \\@\\@");
+        QRegularExpressionMatch match=positionRegex.match(position);
+        if(!match.hasMatch())
         {
             //qDebug()<<position;
             qWarning("Wrong diff output. Expecting unified format");
             return;
         }
-        int line1 = positionRegex.cap(1).toInt();
-        int length1 = positionRegex.cap(2).toInt();
-        int line2 = positionRegex.cap(3).toInt();
-        int length2 = positionRegex.cap(4).toInt();
+        int line1 = match.captured(1).toInt();
+        int length1 = match.captured(2).toInt();
+        int line2 = match.captured(3).toInt();
+        int length2 = match.captured(4).toInt();
         while(length2 > 0 || length1 > 0)
         {
             c = _process.read(1);
