@@ -1,5 +1,5 @@
 /***************************************************************************
- *   copyright       : (C) 2003-2021 by Pascal Brachet                     *
+ *   copyright       : (C) 2003-2023 by Pascal Brachet                     *
  *   https://www.xm1math.net/texmaker/                                     *
  *                                                                         *
  *   addons by Luis Silvestre ; S. Razi Alavizadeh; Robin.Watts            *
@@ -182,7 +182,7 @@ QString sessionTempFile;
 //settings
 bool eraseSettings, replaceSettings;
 QString settingsFileName;
-int split1_right, split1_left, split2_top, split2_bottom, quickmode, tabwidth;
+int split1_right, split1_left, split2_top, split2_bottom, quickmode, tabwidth, autosaveinterval;
 bool singlemode, wordwrap, parenmatch, showline, showoutputview, showstructview, showpdfview, showsourceview, showfilesview, ams_packages, makeidx_package, completion, inlinespellcheck, modern_style, new_gui, builtinpdfview, singleviewerinstance, babel_package, geometry_package, graphicx_package, watchfiles, autosave, tabspaces, useoutputdir ;
 bool lmodern_package, kpfonts_package, fourier_package;
 QString document_class, typeface_size, paper_size, document_encoding, author, geometry_options, babel_default;
