@@ -1,16 +1,16 @@
 /***************************************************************************
- *   copyright       : (C) 2003-2017 by Pascal Brachet                     *
- *   addons by Luis Silvestre                                              *
- *   http://www.xm1math.net/texmaker/                                      *
+ *   copyright       : (C) 2003-2023 by Pascal Brachet                     *
+ *   https://www.xm1math.net/texmaker/                                     *
  *                                                                         *
+ *   addons by Luis Silvestre                                              *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   @license GPL-2.0+ <https://spdx.org/licenses/GPL-2.0+.html>           *
  ***************************************************************************/
 
-
 #include <QDebug>
 #include <QLocale>
 //#include <QSplashScreen>
@@ -19,6 +19,10 @@
 #include <QSettings>
 #include <QFontDatabase>
 #include "texmakerapp.h"
+#define STRINGIFY_INTERNAL(x) #x
+#define STRINGIFY(x) STRINGIFY_INTERNAL(x)
+
+#define VERSION_STR STRINGIFY(TEXMAKERVERSION)
 
 TexmakerApp *TexmakerApp::theAppInstance = NULL;
 
