@@ -1,19 +1,24 @@
 /***************************************************************************
- *   copyright       : (C) 2003-2017 by Pascal Brachet                     *
- *   http://www.xm1math.net/texmaker/                                      *
+ *   copyright       : (C) 2003-2023 by Pascal Brachet                     *
+ *   https://www.xm1math.net/texmaker/                                     *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
+ *   @license GPL-2.0+ <https://spdx.org/licenses/GPL-2.0+.html>           *
  ***************************************************************************/
 
 #include "unicodedialog.h"
-#include <QTextCodec>
 #include <QFileDialog>
 #include <QFile>
 #include <QMessageBox>
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+    #include <QtCore/QTextCodec>
+#else
+    #include <QtCore5Compat/QTextCodec>
+#endif
 
 
 UnicodeDialog::UnicodeDialog(QWidget *parent)
@@ -27,13 +32,13 @@ foreach (int mib, QTextCodec::availableMibs())
 	if (codec->name()!="UTF-8") ui.comboBoxEncoding->addItem(codec->name());
 	}
 ui.comboBoxEncoding->setCurrentIndex(ui.comboBoxEncoding->findText("ISO-8859-1", Qt::MatchExactly));
-connect(ui.comboBoxEncoding, SIGNAL(currentIndexChanged( const QString & ) ), this, SLOT( resetEditor() )); 
+connect(ui.comboBoxEncoding, SIGNAL(currentTextChanged( const QString & ) ), this, SLOT( resetEditor() ));
 connect(ui.lineEdit, SIGNAL(textChanged( const QString & ) ), this, SLOT( resetEditor() )); 
 connect(ui.pushButton, SIGNAL( clicked() ), this, SLOT( chooseFile() ) );
 connect(ui.pushButtonConvert, SIGNAL( clicked() ), this, SLOT( convertFile() ) );
 mainlay = new QVBoxLayout(ui.frameEditor );
 mainlay->setSpacing(0);
-mainlay->setMargin(0);
+mainlay->setContentsMargins(0,0,0,0);
 }
 
 UnicodeDialog::~UnicodeDialog(){
@@ -68,7 +73,7 @@ if ( !file.open( QIODevice::ReadOnly ) )
 QTextCodec* codec = QTextCodec::codecForName(ui.comboBoxEncoding->currentText().toLatin1());
 //if(!codec) codec = QTextCodec::codecForLocale();
 unicodeviewWidget->editor->setPlainText(codec->toUnicode(file.readAll()));
-
+file.close();
 }
 
 void UnicodeDialog::resetEditor()
